'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

function _interopDefault (ex) { return (ex && (typeof ex === 'object') && 'default' in ex) ? ex['default'] : ex; }

var styled = require('styled-components');
var styled__default = _interopDefault(styled);
var React = _interopDefault(require('react'));
var reactRouterDom = require('react-router-dom');

function buildMediaQuery({ minWidth, maxWidth }, not) {
    let query = '';
    if (minWidth) {
        query += `(min-width: ${minWidth}px)`;
    }
    if (minWidth && maxWidth) {
        query += ' and ';
    }
    if (maxWidth) {
        query += `(max-width: ${maxWidth}px)`;
    }
    if (not) {
        query = `not all and ${query}`;
    }
    return query;
}
const SIZES = {
    sm: { maxWidth: 1023 },
    md: {},
    lg: { minWidth: 1024 },
};
const media = {
    sm(first, ...interpolations) {
        const mediaQuery = buildMediaQuery(SIZES.sm);
        return styled.css `
      @media ${mediaQuery} {
        ${styled.css(first, ...interpolations)};
      }
    `;
    },
    md(first, ...interpolations) {
        const mediaQuery = buildMediaQuery(SIZES.md);
        return styled.css `
      @media ${mediaQuery} {
        ${styled.css(first, ...interpolations)};
      }
    `;
    },
    lg(first, ...interpolations) {
        const mediaQuery = buildMediaQuery(SIZES.lg);
        return styled.css `
      @media ${mediaQuery} {
        ${styled.css(first, ...interpolations)};
      }
    `;
    },
};

var index = /*#__PURE__*/Object.freeze({
  buildMediaQuery: buildMediaQuery,
  default: buildMediaQuery,
  SIZES: SIZES,
  media: media
});

const white = '#FFF';
const black = '#000';
const gray000 = '#f8f8f9';
const gray50 = gray000;
const gray100 = '#edeff0';
const gray200 = '#dde0e2';
const gray300 = '#cdd1d4';
const gray400 = '#bdc2c6';
const gray500 = '#a8aeb3';
const gray600 = '#858a8d';
const gray700 = '#616568';
const gray800 = '#3e4042';
const gray900 = '#1b1c1d';
const red000 = '#fff0f0';
const red50 = red000;
const red100 = '#ffd9d9';
const red200 = '#ffc9c9';
const red300 = '#f7abb0';
const red400 = '#f28896';
const red500 = '#ed6b85';
const red600 = '#e52c60';
const red700 = '#e0004d';
const red800 = '#c20042';
const red900 = '#a40038';
const redError = '#ff5252';
const orange000 = '#fff9f2';
const orange50 = orange000;
const orange100 = '#ffe8cc';
const orange200 = '#ffd8a8';
const orange300 = '#ffc078';
const orange400 = '#ffa94d';
const orange500 = '#ff922b';
const orange600 = '#fd7e14';
const orange700 = '#f76707';
const orange800 = '#e8590c';
const orange900 = '#d9480f';
const blue000 = '#e8fbfc';
const blue100 = '#d0eff5';
const blue200 = '#b0dfeb';
const blue300 = '#96cee0';
const blue400 = '#7abdd3';
const blue500 = '#5faec9';
const blue600 = '#459fbf';
const blue700 = '#2a8fb4';
const blue800 = '#1080aa';
const blue900 = '#0e7196';
const green500 = '#00b79d';

var index$1 = /*#__PURE__*/Object.freeze({
  white: white,
  black: black,
  gray000: gray000,
  gray50: gray50,
  gray100: gray100,
  gray200: gray200,
  gray300: gray300,
  gray400: gray400,
  gray500: gray500,
  gray600: gray600,
  gray700: gray700,
  gray800: gray800,
  gray900: gray900,
  red000: red000,
  red50: red50,
  red100: red100,
  red200: red200,
  red300: red300,
  red400: red400,
  red500: red500,
  red600: red600,
  red700: red700,
  red800: red800,
  red900: red900,
  redError: redError,
  orange000: orange000,
  orange50: orange50,
  orange100: orange100,
  orange200: orange200,
  orange300: orange300,
  orange400: orange400,
  orange500: orange500,
  orange600: orange600,
  orange700: orange700,
  orange800: orange800,
  orange900: orange900,
  blue000: blue000,
  blue100: blue100,
  blue200: blue200,
  blue300: blue300,
  blue400: blue400,
  blue500: blue500,
  blue600: blue600,
  blue700: blue700,
  blue800: blue800,
  blue900: blue900,
  green500: green500
});

class SvgAdd extends React.PureComponent {
    render() {
        return React.createElement("svg", { width: this.props.size, height: this.props.size, viewBox: "0 0 24 24" },
            React.createElement("path", { fill: this.props.fillColor, fillRule: "evenodd", d: "M19 13h-6v6h-2v-6H5v-2h6V5h2v6h6z" }));
    }
}
SvgAdd.defaultProps = {
    fillColor: '#3E4042',
    size: 24
};

class SvgAddCircleOutline extends React.PureComponent {
    render() {
        return React.createElement("svg", { width: this.props.size, height: this.props.size, viewBox: "0 0 24 24" },
            React.createElement("path", { fill: this.props.fillColor, fillRule: "evenodd", d: "M13 7h-2v4H7v2h4v4h2v-4h4v-2h-4V7zm-1-5C6.48 2 2 6.48 2 12s4.48 10 10 10 10-4.48 10-10S17.52 2 12 2zm0 18c-4.41 0-8-3.59-8-8s3.59-8 8-8 8 3.59 8 8-3.59 8-8 8z" }));
    }
}
SvgAddCircleOutline.defaultProps = {
    fillColor: '#3E4042',
    size: 24
};

class SvgAlert extends React.PureComponent {
    render() {
        return React.createElement("svg", { width: this.props.size, height: this.props.size, viewBox: "0 0 24 24" },
            React.createElement("path", { fill: this.props.fillColor, fillRule: "evenodd", d: "M21.872 19.51A1 1 0 0 1 21 21H3a1 1 0 0 1-.872-1.49l9-16a1 1 0 0 1 1.744 0l9 16zM13 15V9h-2v6h2zm0 3v-2h-2v2h2z" }));
    }
}
SvgAlert.defaultProps = {
    fillColor: '#3E4042',
    size: 24
};

class SvgArrow extends React.PureComponent {
    render() {
        return React.createElement("svg", { width: this.props.size, height: this.props.size, viewBox: "0 0 24 24" },
            React.createElement("defs", null,
                React.createElement("path", { id: "arrow_svg__a", d: "M12 4l-1.41 1.41L16.17 11H4v2h12.17l-5.58 5.59L12 20l8-8z" })),
            React.createElement("use", { fill: this.props.fillColor, fillRule: "evenodd", xlinkHref: "#arrow_svg__a" }));
    }
}
SvgArrow.defaultProps = {
    fillColor: '#3E4042',
    size: 24
};

class SvgBell extends React.PureComponent {
    render() {
        return React.createElement("svg", { width: this.props.size, height: this.props.size, viewBox: "0 0 24 24" },
            React.createElement("path", { fill: this.props.fillColor, fillRule: "evenodd", d: "M17 11a5 5 0 1 0-10 0v6h10v-6zm-6.5-6.839V3.5a1.5 1.5 0 0 1 3 0v.661A7.003 7.003 0 0 1 19 11v5.5l1 .5v2H4v-2l1-.5V11a7.003 7.003 0 0 1 5.5-6.839zM10 20h4a2 2 0 1 1-4 0z" }));
    }
}
SvgBell.defaultProps = {
    fillColor: '#3E4042',
    size: 24
};

class SvgBellOff extends React.PureComponent {
    render() {
        return React.createElement("svg", { width: this.props.size, height: this.props.size, viewBox: "0 0 24 24" },
            React.createElement("path", { fill: this.props.fillColor, fillRule: "evenodd", d: "M4.5 19H4v-2l1-.5V11a7.003 7.003 0 0 1 5.5-6.839V3.5a1.5 1.5 0 0 1 3 0v.661a6.993 6.993 0 0 1 3.693 2.146L19.5 4 21 5.5l-2.619 2.619C18.78 8.997 19 9.973 19 11v5.5l1 .5v2H7.5l-3 3L3 20.5 4.5 19zm5-2H17v-6c0-.458-.062-.902-.177-1.323L9.5 17zM7 16.5l8.777-8.777A5 5 0 0 0 7 11v5.5zm3 3.5h4a2 2 0 1 1-4 0z" }));
    }
}
SvgBellOff.defaultProps = {
    fillColor: '#3E4042',
    size: 24
};

class SvgBookmark extends React.PureComponent {
    render() {
        return React.createElement("svg", { width: this.props.size, height: this.props.size, viewBox: "0 0 24 24" },
            React.createElement("path", { fill: this.props.fillColor, fillRule: "evenodd", d: "M17 5H7.009l-.007 12.966L12 15.824l5 2.143V5zm0-2c1.1 0 2 .9 2 2v16l-7-3-7 3 .01-16c0-1.1.89-2 1.99-2h10z" }));
    }
}
SvgBookmark.defaultProps = {
    fillColor: '#3E4042',
    size: 24
};

class SvgBright extends React.PureComponent {
    render() {
        return React.createElement("svg", { width: this.props.size, height: this.props.size, viewBox: "0 0 24 24" },
            React.createElement("path", { fill: this.props.fillColor, fillRule: "evenodd", d: "M19 7a1 1 0 0 1-2 0V3a1 1 0 0 1 2 0v4zm7.485 3.929a1 1 0 0 1-1.414-1.414L27.9 6.686a1 1 0 0 1 1.415 1.415l-2.829 2.828zM29 19a1 1 0 0 1 0-2h4a1 1 0 0 1 0 2h-4zm-3.929 7.485a1 1 0 0 1 1.414-1.414l2.829 2.828a1 1 0 0 1-1.415 1.415l-2.828-2.829zM17 29a1 1 0 0 1 2 0v4a1 1 0 0 1-2 0v-4zm-7.485-3.929a1 1 0 1 1 1.414 1.414L8.1 29.314a1 1 0 1 1-1.415-1.415l2.829-2.828zM7 17a1 1 0 0 1 0 2H3a1 1 0 0 1 0-2h4zm3.929-7.485a1 1 0 1 1-1.414 1.414L6.686 8.1a1 1 0 0 1 1.415-1.415l2.828 2.829zM18 26a8 8 0 1 1 0-16 8 8 0 0 1 0 16zm0-2a6 6 0 1 0 0-12 6 6 0 0 0 0 12z" }));
    }
}
SvgBright.defaultProps = {
    fillColor: '#3E4042',
    size: 24
};

class SvgCamera extends React.PureComponent {
    render() {
        return React.createElement("svg", { width: this.props.size, height: this.props.size, viewBox: "0 0 24 24" },
            React.createElement("path", { fill: this.props.fillColor, fillRule: "evenodd", d: "M9 3h6l1.83 2H20c1.1 0 2 .9 2 2v12c0 1.1-.9 2-2 2H4c-1.1 0-2-.9-2-2V7c0-1.1.9-2 2-2h3.17L9 3zm6.2 10c0 2.133-1.067 3.2-3.2 3.2S8.8 15.133 8.8 13 9.867 9.8 12 9.8s3.2 1.067 3.2 3.2zM12 18c2.76 0 5-2.24 5-5s-2.24-5-5-5-5 2.24-5 5 2.24 5 5 5z" }));
    }
}
SvgCamera.defaultProps = {
    fillColor: '#3E4042',
    size: 24
};

class SvgCategory extends React.PureComponent {
    render() {
        return React.createElement("svg", { width: this.props.size, height: this.props.size, viewBox: "0 0 24 24" },
            React.createElement("path", { fill: this.props.fillColor, fillRule: "evenodd", d: "M3 5h18v2H3V5zm0 6h18v2H3v-2zm0 6h18v2H3v-2z" }));
    }
}
SvgCategory.defaultProps = {
    fillColor: '#3E4042',
    size: 24
};

class SvgCheck extends React.PureComponent {
    render() {
        return React.createElement("svg", { width: this.props.size, height: this.props.size, viewBox: "0 0 24 24" },
            React.createElement("path", { fill: this.props.fillColor, fillRule: "evenodd", d: "M10 18l-6-6 1.5-1.5L10 15l9-9 1.5 1.5z" }));
    }
}
SvgCheck.defaultProps = {
    fillColor: '#3E4042',
    size: 24
};

class SvgCheckCircle extends React.PureComponent {
    render() {
        return React.createElement("svg", { width: this.props.size, height: this.props.size, viewBox: "0 0 24 24" },
            React.createElement("path", { fill: this.props.fillColor, fillRule: "evenodd", d: "M12 2c5.52 0 10 4.48 10 10s-4.48 10-10 10S2 17.52 2 12 6.48 2 12 2zm-1.666 14.795l7.5-7.5-1.175-1.184-6.325 6.326-2.992-2.984-1.175 1.175 4.167 4.167z" }));
    }
}
SvgCheckCircle.defaultProps = {
    fillColor: '#3E4042',
    size: 24
};

class SvgCheckCircleOutline extends React.PureComponent {
    render() {
        return React.createElement("svg", { width: this.props.size, height: this.props.size, viewBox: "0 0 24 24" },
            React.createElement("path", { fill: this.props.fillColor, fillRule: "evenodd", d: "M12 4a8 8 0 1 0 0 16 8 8 0 0 0 0-16zm0 18C6.477 22 2 17.523 2 12S6.477 2 12 2s10 4.477 10 10-4.477 10-10 10zm-1.5-6L17 9.5 15.5 8l-5 5-2-2L7 12.5l3.5 3.5z" }));
    }
}
SvgCheckCircleOutline.defaultProps = {
    fillColor: '#3E4042',
    size: 24
};

class SvgCheckboxIndeterminated extends React.PureComponent {
    render() {
        return React.createElement("svg", { width: this.props.size, height: this.props.size, viewBox: "0 0 24 24" },
            React.createElement("path", { fill: this.props.fillColor, fillRule: "evenodd", d: "M19 3H5c-1.1 0-2 .9-2 2v14c0 1.1.9 2 2 2h14c1.1 0 2-.9 2-2V5c0-1.1-.9-2-2-2zm-2 10H7v-2h10v2z" }));
    }
}
SvgCheckboxIndeterminated.defaultProps = {
    fillColor: '#3E4042',
    size: 24
};

class SvgCheckboxOff extends React.PureComponent {
    render() {
        return React.createElement("svg", { width: this.props.size, height: this.props.size, viewBox: "0 0 24 24" },
            React.createElement("path", { fill: this.props.fillColor, fillRule: "evenodd", d: "M19 19H5V5h14v14zM5 3c-1.1 0-2 .9-2 2v14c0 1.1.9 2 2 2h14c1.1 0 2-.9 2-2V5c0-1.1-.9-2-2-2H5z" }));
    }
}
SvgCheckboxOff.defaultProps = {
    fillColor: '#3E4042',
    size: 24
};

class SvgCheckboxOn extends React.PureComponent {
    render() {
        return React.createElement("svg", { width: this.props.size, height: this.props.size, viewBox: "0 0 24 24" },
            React.createElement("path", { fill: this.props.fillColor, fillRule: "evenodd", d: "M19 3a2 2 0 0 1 2 2v14a2 2 0 0 1-2 2H5a2 2 0 0 1-2-2V5a2 2 0 0 1 2-2h14zm-8.666 13.684l7.5-7.5L16.659 8l-6.325 6.326-2.992-2.984-1.175 1.175 4.167 4.167z" }));
    }
}
SvgCheckboxOn.defaultProps = {
    fillColor: '#3E4042',
    size: 24
};

class SvgChevron extends React.PureComponent {
    render() {
        return React.createElement("svg", { width: this.props.size, height: this.props.size, viewBox: "0 0 24 24" },
            React.createElement("path", { fill: this.props.fillColor, fillRule: "evenodd", d: "M8.5 18.5l6-6.5-6-6.5L10 4l7.5 8-7.5 8z" }));
    }
}
SvgChevron.defaultProps = {
    fillColor: '#3E4042',
    size: 24
};

class SvgChevronDown extends React.PureComponent {
    render() {
        return React.createElement("svg", { width: this.props.size, height: this.props.size, viewBox: "0 0 24 24" },
            React.createElement("path", { fill: this.props.fillColor, fillRule: "evenodd", d: "M5.5 8.5l6.5 6 6.5-6L20 10l-8 7.5L4 10z" }));
    }
}
SvgChevronDown.defaultProps = {
    fillColor: '#3E4042',
    size: 24
};

class SvgClock extends React.PureComponent {
    render() {
        return React.createElement("svg", { width: this.props.size, height: this.props.size, viewBox: "0 0 24 24" },
            React.createElement("path", { fill: this.props.fillColor, fillRule: "evenodd", d: "M11.99 2C6.47 2 2 6.48 2 12s4.47 10 9.99 10C17.52 22 22 17.52 22 12S17.52 2 11.99 2zM12 20c-4.42 0-8-3.58-8-8s3.58-8 8-8 8 3.58 8 8-3.58 8-8 8zm.5-13H11v6l5.25 3.15.75-1.23-4.5-2.67V7z" }));
    }
}
SvgClock.defaultProps = {
    fillColor: '#3E4042',
    size: 24
};

class SvgClose extends React.PureComponent {
    render() {
        return React.createElement("svg", { width: this.props.size, height: this.props.size, viewBox: "0 0 24 24" },
            React.createElement("defs", null,
                React.createElement("path", { id: "close_svg__a", d: "M17.59 5L12 10.59 6.41 5 5 6.41 10.59 12 5 17.59 6.41 19 12 13.41 17.59 19 19 17.59 13.41 12 19 6.41z" })),
            React.createElement("use", { fill: this.props.fillColor, fillRule: "evenodd", xlinkHref: "#close_svg__a" }));
    }
}
SvgClose.defaultProps = {
    fillColor: '#3E4042',
    size: 24
};

class SvgCloseCircle extends React.PureComponent {
    render() {
        return React.createElement("svg", { width: this.props.size, height: this.props.size, viewBox: "0 0 24 24" },
            React.createElement("path", { fill: this.props.fillColor, fillRule: "evenodd", d: "M12 2C6.47 2 2 6.47 2 12s4.47 10 10 10 10-4.47 10-10S17.53 2 12 2zm5 13.59L15.59 17 12 13.41 8.41 17 7 15.59 10.59 12 7 8.41 8.41 7 12 10.59 15.59 7 17 8.41 13.41 12 17 15.59z" }));
    }
}
SvgCloseCircle.defaultProps = {
    fillColor: '#3E4042',
    size: 24
};

class SvgComment extends React.PureComponent {
    render() {
        return React.createElement("svg", { width: this.props.size, height: this.props.size, viewBox: "0 0 24 24" },
            React.createElement("path", { fill: this.props.fillColor, fillRule: "evenodd", d: "M8.948 4h6.104c1.782 0 2.9.278 3.879.801a5.452 5.452 0 0 1 2.268 2.268c.523.978.801 2.097.801 3.879v1.104c0 1.782-.278 2.9-.801 3.879a5.452 5.452 0 0 1-2.268 2.268c-.978.523-2.097.801-3.879.801H14l-2 2-2-2H8.948c-1.782 0-2.9-.278-3.879-.801a5.452 5.452 0 0 1-2.268-2.268C2.278 14.953 2 13.834 2 12.052v-1.104c0-1.782.278-2.9.801-3.879A5.452 5.452 0 0 1 5.07 4.801C6.047 4.278 7.166 4 8.948 4zM8 13a1 1 0 1 0 0-2 1 1 0 0 0 0 2zm4 0a1 1 0 1 0 0-2 1 1 0 0 0 0 2zm4 0a1 1 0 1 0 0-2 1 1 0 0 0 0 2z" }));
    }
}
SvgComment.defaultProps = {
    fillColor: '#3E4042',
    size: 24
};

class SvgCompass extends React.PureComponent {
    render() {
        return React.createElement("svg", { width: this.props.size, height: this.props.size, viewBox: "0 0 24 24" },
            React.createElement("path", { fill: this.props.fillColor, fillRule: "evenodd", d: "M10.65 13.35l3.601.901-.9-3.602-2.702 2.702zM12 22C6.477 22 2 17.523 2 12S6.477 2 12 2s10 4.477 10 10-4.477 10-10 10zm0-2a8 8 0 1 0 0-16 8 8 0 0 0 0 16zm4.596-4.132a1 1 0 0 1-1.213.728L9 15 7.404 8.617a1 1 0 0 1 1.213-1.213L15 9l1.596 6.383a1 1 0 0 1 0 .485z" }));
    }
}
SvgCompass.defaultProps = {
    fillColor: '#3E4042',
    size: 24
};

class SvgConfetti extends React.PureComponent {
    render() {
        return React.createElement("svg", { width: this.props.size, height: this.props.size, viewBox: "0 0 24 24" },
            React.createElement("path", { fill: this.props.fillColor, fillRule: "evenodd", d: "M25.168 16.555L24 14.803l-1.168 1.752a1 1 0 1 1-1.664-1.11l2-3a1 1 0 0 1 1.664 0L26 14.197l1.168-1.752a1 1 0 1 1 1.664 1.11l-2 3a1 1 0 0 1-1.664 0zM16 9v3a1 1 0 0 1-2 0V8a1 1 0 0 1 1-1h3V4a1 1 0 0 1 2 0v4a1 1 0 0 1-1 1h-3zm12 15a2 2 0 1 1 0-4 2 2 0 0 1 0 4zM25 8a1 1 0 1 1 0-2 1 1 0 0 1 0 2zM8 8a2 2 0 1 1 0-4 2 2 0 0 1 0 4zm1.707 4.293l10 10a1 1 0 0 1-.356 1.643l-16 6c-.804.302-1.589-.483-1.287-1.287l6-16a1 1 0 0 1 1.643-.356z" }));
    }
}
SvgConfetti.defaultProps = {
    fillColor: '#3E4042',
    size: 24
};

class SvgContents extends React.PureComponent {
    render() {
        return React.createElement("svg", { width: this.props.size, height: this.props.size, viewBox: "0 0 24 24" },
            React.createElement("path", { fill: this.props.fillColor, fillRule: "evenodd", d: "M4.889 2H19.11a.9.9 0 0 1 .889.91v18.18a.9.9 0 0 1-.889.91H4.89A.9.9 0 0 1 4 21.09V2.91A.9.9 0 0 1 4.889 2zM6 4v6h12V4H6zm0 8v2h12v-2H6zm0 4v2h10v-2H6z" }));
    }
}
SvgContents.defaultProps = {
    fillColor: '#3E4042',
    size: 24
};

class SvgCoupon extends React.PureComponent {
    render() {
        return React.createElement("svg", { width: this.props.size, height: this.props.size, viewBox: "0 0 24 24" },
            React.createElement("path", { fill: this.props.fillColor, fillRule: "evenodd", d: "M16.586 15l-1.293-1.293a1 1 0 0 1 1.414-1.414L18 13.586l3.086-3.086-1.82-1.82a3.002 3.002 0 0 1-3.788-3.788L13.5 2.914 10.414 6l1.293 1.293a1 1 0 1 1-1.414 1.414L9 7.414 2.914 13.5l1.978 1.978a3.002 3.002 0 0 1 3.787 3.787l1.821 1.82L16.586 15zM3.979 17.393L1.5 14.914a2 2 0 0 1 0-2.828L12.086 1.5a2 2 0 0 1 2.828 0l2.48 2.48a1 1 0 0 1 .113 1.278 1 1 0 0 0 1.392 1.392 1 1 0 0 1 1.279.114L22.5 9.086a2 2 0 0 1 0 2.828L11.914 22.5a2 2 0 0 1-2.828 0l-2.322-2.322a1 1 0 0 1-.114-1.28 1 1 0 0 0-1.392-1.391 1 1 0 0 1-1.279-.114zm8.314-6.686a1 1 0 1 1 1.414-1.414l1 1a1 1 0 0 1-1.414 1.414l-1-1z" }));
    }
}
SvgCoupon.defaultProps = {
    fillColor: '#3E4042',
    size: 24
};

class SvgCreditCard extends React.PureComponent {
    render() {
        return React.createElement("svg", { width: this.props.size, height: this.props.size, viewBox: "0 0 24 24" },
            React.createElement("g", { fill: this.props.fillColor, fillRule: "evenodd" },
                React.createElement("path", { d: "M4 12v6h16v-6H4zm0-4h16V6H4v2zM3 4h18c.667 0 1 .333 1 1v14c0 .667-.333 1-1 1H3c-.667 0-1-.333-1-1V5c0-.667.333-1 1-1z" }),
                React.createElement("path", { d: "M6 14h4v2H6z" })));
    }
}
SvgCreditCard.defaultProps = {
    fillColor: '#3E4042',
    size: 24
};

class SvgCrop extends React.PureComponent {
    render() {
        return React.createElement("svg", { width: this.props.size, height: this.props.size, viewBox: "0 0 24 24" },
            React.createElement("path", { fill: this.props.fillColor, fillRule: "evenodd", d: "M6 6V3a1 1 0 0 1 2 0v3h9a1 1 0 0 1 1 1v9.002L21 16a1 1 0 0 1 0 2l-14 .008a1 1 0 0 1-1-1V9h2v7.007l8-.004V8H3a1 1 0 0 1 0-2h3zm12 15a1 1 0 0 1-2 0v-2h2v2z" }));
    }
}
SvgCrop.defaultProps = {
    fillColor: '#3E4042',
    size: 24
};

class SvgCrown extends React.PureComponent {
    render() {
        return React.createElement("svg", { width: this.props.size, height: this.props.size, viewBox: "0 0 24 24" },
            React.createElement("path", { fill: this.props.fillColor, fillRule: "evenodd", d: "M15.96 11.04L21 6v14H3V6l5.04 5.04L12 4l3.96 7.04z" }));
    }
}
SvgCrown.defaultProps = {
    fillColor: '#3E4042',
    size: 24
};

class SvgDepositPassbook extends React.PureComponent {
    render() {
        return React.createElement("svg", { width: this.props.size, height: this.props.size, viewBox: "0 0 24 24" },
            React.createElement("path", { fill: this.props.fillColor, fillRule: "evenodd", d: "M21 13l1.69 6.757A1 1 0 0 1 21.72 21H2.28a1 1 0 0 1-.97-1.243L3 13V4a1 1 0 0 1 1-1h16a1 1 0 0 1 1 1v9zm-2 0V5H5v8h14zM4.562 15l-1 4h16.876l-1-4H4.562zM7 7h10v2H7V7z" }));
    }
}
SvgDepositPassbook.defaultProps = {
    fillColor: '#3E4042',
    size: 24
};

class SvgDownload extends React.PureComponent {
    render() {
        return React.createElement("svg", { width: this.props.size, height: this.props.size, viewBox: "0 0 24 24" },
            React.createElement("path", { fill: this.props.fillColor, fillRule: "evenodd", d: "M19 19v-6h2v7a1 1 0 0 1-1 1H4a1 1 0 0 1-1-1v-7h2v6h14zm-6-7.827l3.586-3.587L18 9l-6 6.001L6 9l1.414-1.414L11 11.173V3h2v8.173z" }));
    }
}
SvgDownload.defaultProps = {
    fillColor: '#3E4042',
    size: 24
};

class SvgDropDown extends React.PureComponent {
    render() {
        return React.createElement("svg", { width: this.props.size, height: this.props.size, viewBox: "0 0 24 24" },
            React.createElement("path", { fillRule: "evenodd", d: "M17 10l-5 5-5-5z" }));
    }
}
SvgDropDown.defaultProps = {
    fillColor: '#3E4042',
    size: 24
};

class SvgEarybird extends React.PureComponent {
    render() {
        return React.createElement("svg", { width: this.props.size, height: this.props.size, viewBox: "0 0 24 24" },
            React.createElement("path", { fill: this.props.fillColor, fillRule: "evenodd", d: "M3 5.315h2.14c1.557-1.218 3.043-1.59 4.456-1.116 2.12.712 2.603 2.118 2.58 3.801v.896a9.543 9.543 0 0 0 8.058-4.056s3.58 8.057-4.477 11.638C17.601 17.73 19.773 18.088 22 18c-2 1-4 2-7 2C9 20 4 15.577 4 9c0-.667.064-1.257.19-1.77A61.884 61.884 0 0 1 3 5.315z" }));
    }
}
SvgEarybird.defaultProps = {
    fillColor: '#3E4042',
    size: 24
};

class SvgEdit extends React.PureComponent {
    render() {
        return React.createElement("svg", { width: this.props.size, height: this.props.size, viewBox: "0 0 24 24" },
            React.createElement("path", { fill: this.props.fillColor, fillRule: "evenodd", d: "M4 21a1 1 0 0 1-1-1v-4a1 1 0 0 1 .293-.707l11-11a3.828 3.828 0 0 1 5.414 5.414l-11 11A1 1 0 0 1 8 21H4zm1-2h2.586l.707-.707-2.586-2.586-.707.707V19z" }));
    }
}
SvgEdit.defaultProps = {
    fillColor: '#3E4042',
    size: 24
};

class SvgEditBody extends React.PureComponent {
    render() {
        return React.createElement("svg", { width: this.props.size, height: this.props.size, viewBox: "0 0 24 24" },
            React.createElement("path", { fill: this.props.fillColor, fillRule: "evenodd", d: "M9 4.5v3h5v12h3v-12h5v-3H9zm-6 8h3v7h3v-7h3v-3H3v3z" }));
    }
}
SvgEditBody.defaultProps = {
    fillColor: '#3E4042',
    size: 24
};

class SvgEditBold extends React.PureComponent {
    render() {
        return React.createElement("svg", { width: this.props.size, height: this.props.size, viewBox: "0 0 24 24" },
            React.createElement("path", { fill: this.props.fillColor, fillRule: "evenodd", d: "M15.6 11.79c.97-.67 1.65-1.77 1.65-2.79 0-2.26-1.75-4-4-4H7v14h7.04c2.09 0 3.71-1.7 3.71-3.79 0-1.52-.86-2.82-2.15-3.42zM10 7.5h3c.83 0 1.5.67 1.5 1.5s-.67 1.5-1.5 1.5h-3v-3zm3.5 9H10v-3h3.5c.83 0 1.5.67 1.5 1.5s-.67 1.5-1.5 1.5z" }));
    }
}
SvgEditBold.defaultProps = {
    fillColor: '#3E4042',
    size: 24
};

class SvgEditBullet extends React.PureComponent {
    render() {
        return React.createElement("svg", { width: this.props.size, height: this.props.size, viewBox: "0 0 24 24" },
            React.createElement("path", { fill: this.props.fillColor, fillRule: "evenodd", d: "M4 10.5c-.83 0-1.5.67-1.5 1.5s.67 1.5 1.5 1.5 1.5-.67 1.5-1.5-.67-1.5-1.5-1.5zm0-6c-.83 0-1.5.67-1.5 1.5S3.17 7.5 4 7.5 5.5 6.83 5.5 6 4.83 4.5 4 4.5zm0 12c-.83 0-1.5.68-1.5 1.5s.68 1.5 1.5 1.5 1.5-.68 1.5-1.5-.67-1.5-1.5-1.5zM7 19h14v-2H7v2zm0-6h14v-2H7v2zm0-8v2h14V5H7z" }));
    }
}
SvgEditBullet.defaultProps = {
    fillColor: '#3E4042',
    size: 24
};

class SvgEditNumber extends React.PureComponent {
    render() {
        return React.createElement("svg", { width: this.props.size, height: this.props.size, viewBox: "0 0 24 24" },
            React.createElement("path", { fill: this.props.fillColor, fillRule: "evenodd", d: "M2 17h2v.5H3v1h1v.5H2v1h3v-4H2v1zm1-9h1V4H2v1h1v3zm-1 3h1.8L2 13.1v.9h3v-1H3.2L5 10.9V10H2v1zm5-6v2h14V5H7zm0 14h14v-2H7v2zm0-6h14v-2H7v2z" }));
    }
}
SvgEditNumber.defaultProps = {
    fillColor: '#3E4042',
    size: 24
};

class SvgEditOutline extends React.PureComponent {
    render() {
        return React.createElement("svg", { width: this.props.size, height: this.props.size, viewBox: "0 0 24 24" },
            React.createElement("path", { fill: this.props.fillColor, fillRule: "evenodd", d: "M13.5 7.914l-8.5 8.5V19h2.586l8.5-8.5L13.5 7.914zM14.914 6.5L17.5 9.086l.793-.793a1.828 1.828 0 0 0-2.586-2.586l-.793.793zM4 21a1 1 0 0 1-1-1v-4a1 1 0 0 1 .293-.707l11-11a3.828 3.828 0 0 1 5.414 5.414l-11 11A1 1 0 0 1 8 21H4z" }));
    }
}
SvgEditOutline.defaultProps = {
    fillColor: '#3E4042',
    size: 24
};

class SvgEye extends React.PureComponent {
    render() {
        return React.createElement("svg", { width: this.props.size, height: this.props.size, viewBox: "0 0 24 24" },
            React.createElement("path", { fill: this.props.fillColor, fillRule: "evenodd", d: "M1 12s4-8 11-8 11 8 11 8-4 8-11 8-11-8-11-8zm2.31 0l.104.165a17.523 17.523 0 0 0 1.92 2.467C7.334 16.765 9.572 18 12 18s4.666-1.235 6.666-3.368A17.523 17.523 0 0 0 20.69 12a17.523 17.523 0 0 0-2.025-2.632C16.666 7.235 14.428 6 12 6S7.334 7.235 5.334 9.368A17.523 17.523 0 0 0 3.31 12zM12 8a1 1 0 0 1 0 2 2 2 0 1 0 2 2 1 1 0 0 1 2 0 4 4 0 1 1-4-4z" }));
    }
}
SvgEye.defaultProps = {
    fillColor: '#3E4042',
    size: 24
};

class SvgFullScreen extends React.PureComponent {
    render() {
        return React.createElement("svg", { width: this.props.size, height: this.props.size, viewBox: "0 0 24 24" },
            React.createElement("path", { fill: this.props.fillColor, fillRule: "evenodd", d: "M4 10V4h6v2H6v4H4zm0 4h2v2.5L8.5 14l1.5 1.5L7.5 18H10v2H4v-6zm16-4h-2V7.5L15.5 10 14 8.5 16.5 6H14V4h6v6zm0 4v6h-6v-2h4v-4h2z" }));
    }
}
SvgFullScreen.defaultProps = {
    fillColor: '#3E4042',
    size: 24
};

class SvgFullScreenExit extends React.PureComponent {
    render() {
        return React.createElement("svg", { width: this.props.size, height: this.props.size, viewBox: "0 0 24 24" },
            React.createElement("path", { fill: this.props.fillColor, fillRule: "evenodd", d: "M10 4v6H4V8h4V4h2zm4 16v-6h6v2h-4v4h-2zm-4 0H8v-2.5L5.5 20 4 18.5 6.5 16H4v-2h6v6zm4-16h2v2.5L18.5 4 20 5.5 17.5 8H20v2h-6V4z" }));
    }
}
SvgFullScreenExit.defaultProps = {
    fillColor: '#3E4042',
    size: 24
};

class SvgGear extends React.PureComponent {
    render() {
        return React.createElement("svg", { width: this.props.size, height: this.props.size, viewBox: "0 0 24 24" },
            React.createElement("path", { fill: this.props.fillColor, fillRule: "evenodd", d: "M19.43 12.98c.04-.32.07-.64.07-.98 0-.34-.03-.66-.07-.98l2.11-1.65c.19-.15.24-.42.12-.64l-2-3.46c-.12-.22-.39-.3-.61-.22l-2.49 1c-.52-.4-1.08-.73-1.69-.98l-.38-2.65A.488.488 0 0 0 14 2h-4c-.25 0-.46.18-.49.42l-.38 2.65c-.61.25-1.17.59-1.69.98l-2.49-1c-.23-.09-.49 0-.61.22l-2 3.46c-.13.22-.07.49.12.64l2.11 1.65c-.04.32-.07.65-.07.98 0 .33.03.66.07.98l-2.11 1.65c-.19.15-.24.42-.12.64l2 3.46c.12.22.39.3.61.22l2.49-1c.52.4 1.08.73 1.69.98l.38 2.65c.03.24.24.42.49.42h4c.25 0 .46-.18.49-.42l.38-2.65c.61-.25 1.17-.59 1.69-.98l2.49 1c.23.09.49 0 .61-.22l2-3.46c.12-.22.07-.49-.12-.64l-2.11-1.65zM12 15.5c-1.93 0-3.5-1.57-3.5-3.5s1.57-3.5 3.5-3.5 3.5 1.57 3.5 3.5-1.57 3.5-3.5 3.5z" }));
    }
}
SvgGear.defaultProps = {
    fillColor: '#3E4042',
    size: 24
};

class SvgGift extends React.PureComponent {
    render() {
        return React.createElement("svg", { width: this.props.size, height: this.props.size, viewBox: "0 0 24 24" },
            React.createElement("path", { fill: this.props.fillColor, fillRule: "evenodd", d: "M11 10H4v2h7v-2zm2 0v2h7v-2h-7zm-2 4H5v6h6v-6zm2 0v6h6v-6h-6zM5.535 8A4 4 0 0 1 12 3.354 4 4 0 0 1 18.465 8H20c1.219 0 2 .781 2 2v2c0 .843-.374 1.477-1.008 1.788.005.069.008.14.008.212v6c0 1.219-.781 2-2 2H5c-1.219 0-2-.781-2-2v-6c0-.072.003-.143.008-.212C2.374 13.478 2 12.843 2 12v-2c0-1.219.781-2 2-2h1.535zM15 8a2 2 0 1 0-2-2v2h2zm-4-2a2 2 0 1 0-2 2h2V6z" }));
    }
}
SvgGift.defaultProps = {
    fillColor: '#3E4042',
    size: 24
};

class SvgGroove extends React.PureComponent {
    render() {
        return React.createElement("svg", { width: this.props.size, height: this.props.size, viewBox: "0 0 24 24" },
            React.createElement("path", { fill: this.props.fillColor, fillRule: "evenodd", d: "M7 8h10V6H7v2zm0 5h10v-2H7v2zm0 5h10v-2H7v2z" }));
    }
}
SvgGroove.defaultProps = {
    fillColor: '#3E4042',
    size: 24
};

class SvgHeart extends React.PureComponent {
    render() {
        return React.createElement("svg", { width: this.props.size, height: this.props.size, viewBox: "0 0 24 24" },
            React.createElement("path", { fill: this.props.fillColor, fillRule: "evenodd", d: "M5 16.5c-1.911-1.911-3.5-3.962-3.5-7A5.5 5.5 0 0 1 7 4c2.5 0 4 1.5 5 2.5 1-1 2.5-2.5 5-2.5a5.5 5.5 0 0 1 5.5 5.5c0 3.038-1.589 5.089-3.5 7-1.333 1.333-3.667 2.833-7 4.5-3.333-1.667-5.667-3.167-7-4.5z" }));
    }
}
SvgHeart.defaultProps = {
    fillColor: '#3E4042',
    size: 24
};

class SvgHeartOutline extends React.PureComponent {
    render() {
        return React.createElement("svg", { width: this.props.size, height: this.props.size, viewBox: "0 0 24 24" },
            React.createElement("path", { fill: this.props.fillColor, fillRule: "evenodd", d: "M17.586 15.086c2.07-2.07 2.914-3.572 2.914-5.586A3.5 3.5 0 0 0 17 6c-1.074 0-1.92.392-2.829 1.19a14.88 14.88 0 0 0-.757.724L12 9.328l-1.414-1.414a14.88 14.88 0 0 0-.757-.724C8.919 6.392 8.074 6 7 6a3.5 3.5 0 0 0-3.5 3.5c0 2.014.844 3.516 2.914 5.586 1.038 1.037 2.91 2.277 5.586 3.67 2.677-1.393 4.548-2.633 5.586-3.67zM5 16.5c-1.911-1.911-3.5-3.962-3.5-7A5.5 5.5 0 0 1 7 4c2.5 0 4 1.5 5 2.5 1-1 2.5-2.5 5-2.5a5.5 5.5 0 0 1 5.5 5.5c0 3.038-1.589 5.089-3.5 7-1.333 1.333-3.667 2.833-7 4.5-3.333-1.667-5.667-3.167-7-4.5z" }));
    }
}
SvgHeartOutline.defaultProps = {
    fillColor: '#3E4042',
    size: 24
};

class SvgHelp extends React.PureComponent {
    render() {
        return React.createElement("svg", { width: this.props.size, height: this.props.size, viewBox: "0 0 24 24" },
            React.createElement("path", { fill: this.props.fillColor, fillRule: "evenodd", d: "M11 18h2v-2h-2v2zm1-16C6.48 2 2 6.48 2 12s4.48 10 10 10 10-4.48 10-10S17.52 2 12 2zm0 18c-4.41 0-8-3.59-8-8s3.59-8 8-8 8 3.59 8 8-3.59 8-8 8zm0-14c-2.21 0-4 1.79-4 4h2c0-1.1.9-2 2-2s2 .9 2 2c0 2-3 1.75-3 5h2c0-2.25 3-2.5 3-5 0-2.21-1.79-4-4-4z" }));
    }
}
SvgHelp.defaultProps = {
    fillColor: '#3E4042',
    size: 24
};

class SvgHome extends React.PureComponent {
    render() {
        return React.createElement("svg", { width: this.props.size, height: this.props.size, viewBox: "0 0 24 24" },
            React.createElement("path", { fill: this.props.fillColor, fillRule: "evenodd", d: "M5.957 9.71A1 1 0 0 1 6 10v9h3v-4a1 1 0 0 1 1-1h4a1 1 0 0 1 1 1v4h3v-9a1 1 0 0 1 .043-.29l-2.207-1.963L12 4.338 5.957 9.709zM4 11.45l-.336.297a1 1 0 1 1-1.328-1.494l9-8a1 1 0 0 1 1.328 0l4.5 4 4.5 4a1 1 0 0 1-1.328 1.494L20 11.45V20a1 1 0 0 1-1 1h-5a1 1 0 0 1-1-1v-4h-2v4a1 1 0 0 1-1 1H5a1 1 0 0 1-1-1v-8.55z" }));
    }
}
SvgHome.defaultProps = {
    fillColor: '#3E4042',
    size: 24
};

class SvgInfo extends React.PureComponent {
    render() {
        return React.createElement("svg", { width: this.props.size, height: this.props.size, viewBox: "0 0 24 24" },
            React.createElement("path", { fill: this.props.fillColor, fillRule: "evenodd", d: "M19.071 19.071C17.118 21.024 14.761 22 12 22s-5.118-.976-7.071-2.929C2.976 17.118 2 14.761 2 12s.976-5.118 2.929-7.071C6.882 2.976 9.239 2 12 2s5.118.976 7.071 2.929C21.024 6.882 22 9.239 22 12s-.976 5.118-2.929 7.071zM11 11v6h2v-6h-2zm0-4v2h2V7h-2z" }));
    }
}
SvgInfo.defaultProps = {
    fillColor: '#3E4042',
    size: 24
};

class SvgLeaf extends React.PureComponent {
    render() {
        return React.createElement("svg", { width: this.props.size, height: this.props.size, viewBox: "0 0 24 24" },
            React.createElement("path", { fill: "#D7CAA4", d: "M7.22 20.985a3.63 3.63 0 0 1-.053-.005 18.575 18.575 0 0 1-2.443 1.467.5.5 0 1 1-.447-.894c.578-.29 1.14-.611 1.688-.966C5.21 20.121 4.722 19.258 4.5 18c-.347-1.97-.014-3.636 1-5 1.653.697 2.653 2.03 3 4 .096.543.14 1.037.132 1.483a21.532 21.532 0 0 0 2.08-2.279c-.92-.231-1.639-.865-2.157-1.9-.666-1.333-.666-3.333 0-6 2 .8 3.334 2.119 4 3.957.093.255.166.5.22.737.384-.785.677-1.568.88-2.35C12.218 9.912 11.5 8.696 11.5 7c0-2 1-4 3-6 2 2 3 4 3 6 0 1.964-.964 3.285-2.893 3.963-.172.647-.4 1.293-.685 1.938a5.71 5.71 0 0 1 .563-.322c1.333-.666 3.333-.666 6 0-.735 2.816-2.068 4.483-4 5-1.786.479-3.297.029-4.532-1.35a23.568 23.568 0 0 1-1.872 2.222c.105-.005.213-.007.323-.007 1.768 0 3.32.38 4.652 1.141-.908 1.981-2.362 2.971-4.362 2.971-1.786 0-2.944-.523-3.474-1.571z" }));
    }
}
SvgLeaf.defaultProps = {
    fillColor: '#3E4042',
    size: 24
};

class SvgLeesonTime extends React.PureComponent {
    render() {
        return React.createElement("svg", { width: this.props.size, height: this.props.size, viewBox: "0 0 24 24" },
            React.createElement("path", { fill: this.props.fillColor, fillRule: "evenodd", d: "M17 4h2.005C20.107 4 21 4.89 21 6v13c0 1.105-.893 2-1.995 2H4.995A1.994 1.994 0 0 1 3 19V6c0-1.105.893-2 1.995-2H7V2h3v2h4V2h3v2zm2 15V8H5v11h14zm-6-6h4.09v4.09H13V13z" }));
    }
}
SvgLeesonTime.defaultProps = {
    fillColor: '#3E4042',
    size: 24
};

class SvgLike extends React.PureComponent {
    render() {
        return React.createElement("svg", { width: this.props.size, height: this.props.size, viewBox: "0 0 24 24" },
            React.createElement("path", { fill: this.props.fillColor, fillRule: "evenodd", d: "M4 11.495c0-.55.443-.995.999-.995h1.002c.552 0 .999.456.999.995v8.01c0 .55-.443.995-.999.995H4.999c-.552 0-.999-.456-.999-.995v-8.01zM14 9.5h5.604a2 2 0 0 1 1.967 2.358l-1.422 7.82a1 1 0 0 1-.984.822H10a1 1 0 0 1-1-1v-9L12 3c1.5 0 2.5 1 2.5 2.5 0 1-.167 2.333-.5 4z" }));
    }
}
SvgLike.defaultProps = {
    fillColor: '#3E4042',
    size: 24
};

class SvgLikeOutline extends React.PureComponent {
    render() {
        return React.createElement("svg", { width: this.props.size, height: this.props.size, viewBox: "0 0 24 24" },
            React.createElement("path", { fill: this.props.fillColor, fillRule: "evenodd", d: "M4 11.495c0-.55.443-.995.999-.995h1.002c.552 0 .999.456.999.995v8.01c0 .55-.443.995-.999.995H4.999c-.552 0-.999-.456-.999-.995v-8.01zM19.64 8.5a2 2 0 0 1 1.972 2.329l-1.473 8.835a1 1 0 0 1-.986.836H10a1 1 0 0 1-1-1v-9L12 3h1.405a3 3 0 0 1 3 3c0 .112-.135.945-.405 2.5h3.64zM11 10.885V18.5h7.306l1.333-8h-6.035l.785-4.321A1 1 0 0 0 13.405 5h-.05L11 10.885z" }));
    }
}
SvgLikeOutline.defaultProps = {
    fillColor: '#3E4042',
    size: 24
};

class SvgLink extends React.PureComponent {
    render() {
        return React.createElement("svg", { width: this.props.size, height: this.props.size, viewBox: "0 0 24 24" },
            React.createElement("path", { fill: this.props.fillColor, fillRule: "evenodd", d: "M5 19h14v-5h2v6a1 1 0 0 1-1 1H4a1 1 0 0 1-1-1V4a1 1 0 0 1 1-1h6v2H5v14zm16-9h-2V6.5L13.5 12 12 10.5 17.5 5H14V3h7v7z" }));
    }
}
SvgLink.defaultProps = {
    fillColor: '#3E4042',
    size: 24
};

class SvgLocation extends React.PureComponent {
    render() {
        return React.createElement("svg", { width: this.props.size, height: this.props.size, viewBox: "0 0 24 24" },
            React.createElement("g", { fill: "none", fillRule: "evenodd" },
                React.createElement("path", { fill: this.props.fillColor, d: "M12.549 19.512a24.131 24.131 0 0 0 2.475-2.262c2.185-2.306 3.476-4.674 3.476-6.917 0-1.805-.628-3.318-1.905-4.594C15.32 4.463 13.805 3.836 12 3.836c-1.805 0-3.319.627-4.595 1.903C6.128 7.015 5.5 8.529 5.5 10.333c0 2.243 1.291 4.61 3.476 6.917A24.131 24.131 0 0 0 12 19.936c.172-.129.356-.27.549-.424zm7.951-9.179c0 2.862-1.521 5.65-4.024 8.292a26.108 26.108 0 0 1-3.568 3.126c-.164.119-.285.202-.353.248l-.555.37-.555-.37a12.457 12.457 0 0 1-.353-.248 26.108 26.108 0 0 1-3.568-3.126C5.021 15.983 3.5 13.195 3.5 10.333c0-2.336.839-4.357 2.49-6.009C7.644 2.674 9.665 1.836 12 1.836s4.357.837 6.01 2.488c1.651 1.652 2.49 3.673 2.49 6.009z" }),
                React.createElement("path", { fill: "#000", d: "M13.75 10.333c0-1.252-.498-1.75-1.75-1.75s-1.75.498-1.75 1.75c0 1.253.498 1.75 1.75 1.75s1.75-.497 1.75-1.75zm1.5 0c0 2.081-1.17 3.25-3.25 3.25s-3.25-1.169-3.25-3.25c0-2.08 1.17-3.25 3.25-3.25s3.25 1.17 3.25 3.25z" })));
    }
}
SvgLocation.defaultProps = {
    fillColor: '#3E4042',
    size: 24
};

class SvgLock extends React.PureComponent {
    render() {
        return React.createElement("svg", { width: this.props.size, height: this.props.size, viewBox: "0 0 24 24" },
            React.createElement("path", { fill: this.props.fillColor, fillRule: "evenodd", d: "M6 10V7a6 6 0 1 1 12 0v3h1c.667 0 1 .333 1 1v10c0 .667-.333 1-1 1H5c-.667 0-1-.333-1-1V11c0-.667.333-1 1-1h1zm2 0h8V7a4 4 0 1 0-8 0v3zm3 6.732V18a1 1 0 0 0 2 0v-1.268a2 2 0 1 0-2 0z" }));
    }
}
SvgLock.defaultProps = {
    fillColor: '#3E4042',
    size: 24
};

class SvgLockOutline extends React.PureComponent {
    render() {
        return React.createElement("svg", { width: this.props.size, height: this.props.size, viewBox: "0 0 24 24" },
            React.createElement("path", { fill: this.props.fillColor, fillRule: "evenodd", d: "M11 16.732a2 2 0 1 1 2 0V18a1 1 0 0 1-2 0v-1.268zM6 10V7a6 6 0 1 1 12 0v3h1c.667 0 1 .333 1 1v10c0 .667-.333 1-1 1H5c-.667 0-1-.333-1-1V11c0-.667.333-1 1-1h1zm2 0h8V7a4 4 0 1 0-8 0v3zm-2 2v8h12v-8H6z" }));
    }
}
SvgLockOutline.defaultProps = {
    fillColor: '#3E4042',
    size: 24
};

class SvgLockOutlineOff extends React.PureComponent {
    render() {
        return React.createElement("svg", { width: this.props.size, height: this.props.size, viewBox: "0 0 24 24" },
            React.createElement("path", { fill: this.props.fillColor, fillRule: "evenodd", d: "M11 16.732a2 2 0 1 1 2 0V18a1 1 0 0 1-2 0v-1.268zM8 10h11c.667 0 1 .333 1 1v10c0 .667-.333 1-1 1H5c-.667 0-1-.333-1-1V11c0-.667.333-1 1-1h1V7a6 6 0 1 1 12 0 1 1 0 0 1-2 0 4 4 0 1 0-8 0v3zm-2 2v8h12v-8H6z" }));
    }
}
SvgLockOutlineOff.defaultProps = {
    fillColor: '#3E4042',
    size: 24
};

class SvgLogout extends React.PureComponent {
    render() {
        return React.createElement("svg", { width: this.props.size, height: this.props.size, viewBox: "0 0 24 24" },
            React.createElement("path", { fill: this.props.fillColor, fillRule: "evenodd", d: "M5 19h5v-3h2v4a1 1 0 0 1-1 1H4a1 1 0 0 1-1-1V4a1 1 0 0 1 1-1h7a1 1 0 0 1 1 1v4h-2V5H5v14zm12.173-8l-3.587-3.586L15 6l6.001 6L15 18l-1.414-1.414L17.173 13H9v-2h8.173z" }));
    }
}
SvgLogout.defaultProps = {
    fillColor: '#3E4042',
    size: 24
};

class SvgMenu extends React.PureComponent {
    render() {
        return React.createElement("svg", { width: this.props.size, height: this.props.size, viewBox: "0 0 24 24" },
            React.createElement("path", { fill: this.props.fillColor, fillRule: "evenodd", d: "M3 8h18V6H3v2zm0 5h18v-2H3v2zm0 5h18v-2H3v2z" }));
    }
}
SvgMenu.defaultProps = {
    fillColor: '#3E4042',
    size: 24
};

class SvgMessage extends React.PureComponent {
    render() {
        return React.createElement("svg", { width: this.props.size, height: this.props.size, viewBox: "0 0 24 24" },
            React.createElement("path", { fill: this.props.fillColor, fillRule: "evenodd", d: "M20 4c1.1 0 2 .9 2 2v12c0 1.1-.9 2-2 2H4c-1.1 0-2-.9-2-2l.01-12c0-1.1.89-2 1.99-2h16zM6.555 7.168a1 1 0 0 0-1.11 1.664l6 4a1 1 0 0 0 1.11 0l6-4a1 1 0 1 0-1.11-1.664L12 10.798l-5.445-3.63z" }));
    }
}
SvgMessage.defaultProps = {
    fillColor: '#3E4042',
    size: 24
};

class SvgMessageOutline extends React.PureComponent {
    render() {
        return React.createElement("svg", { width: this.props.size, height: this.props.size, viewBox: "0 0 24 24" },
            React.createElement("path", { fill: this.props.fillColor, fillRule: "evenodd", d: "M4 4h16a2 2 0 0 1 2 2v12a2 2 0 0 1-2 2H4a2 2 0 0 1-2-2V6a2 2 0 0 1 2-2zm0 2v12h16V6H4zm3.514 2.143L12 10.833l4.486-2.69a1 1 0 1 1 1.028 1.714l-5 3a1 1 0 0 1-1.028 0l-5-3a1 1 0 1 1 1.028-1.714z" }));
    }
}
SvgMessageOutline.defaultProps = {
    fillColor: '#3E4042',
    size: 24
};

class SvgMinus extends React.PureComponent {
    render() {
        return React.createElement("svg", { width: this.props.size, height: this.props.size, viewBox: "0 0 24 24" },
            React.createElement("path", { fill: this.props.fillColor, fillRule: "evenodd", d: "M4 11h16v2H4z" }));
    }
}
SvgMinus.defaultProps = {
    fillColor: '#3E4042',
    size: 24
};

class SvgMinusCircle extends React.PureComponent {
    render() {
        return React.createElement("svg", { width: this.props.size, height: this.props.size, viewBox: "0 0 24 24" },
            React.createElement("path", { fill: this.props.fillColor, fillRule: "evenodd", d: "M7 11v2h10v-2H7zm5-9C6.48 2 2 6.48 2 12s4.48 10 10 10 10-4.48 10-10S17.52 2 12 2zm0 18c-4.41 0-8-3.59-8-8s3.59-8 8-8 8 3.59 8 8-3.59 8-8 8z" }));
    }
}
SvgMinusCircle.defaultProps = {
    fillColor: '#3E4042',
    size: 24
};

class SvgMoreHorizontal extends React.PureComponent {
    render() {
        return React.createElement("svg", { width: this.props.size, height: this.props.size, viewBox: "0 0 24 24" },
            React.createElement("path", { fill: this.props.fillColor, fillRule: "evenodd", d: "M16 12c0 1.1.9 2 2 2s2-.9 2-2-.9-2-2-2-2 .9-2 2zm-2 0c0-1.1-.9-2-2-2s-2 .9-2 2 .9 2 2 2 2-.9 2-2zm-6 0c0-1.1-.9-2-2-2s-2 .9-2 2 .9 2 2 2 2-.9 2-2z" }));
    }
}
SvgMoreHorizontal.defaultProps = {
    fillColor: '#3E4042',
    size: 24
};

class SvgMoreVertical extends React.PureComponent {
    render() {
        return React.createElement("svg", { width: this.props.size, height: this.props.size, viewBox: "0 0 24 24" },
            React.createElement("path", { fill: this.props.fillColor, fillRule: "evenodd", d: "M12 8c1.1 0 2-.9 2-2s-.9-2-2-2-2 .9-2 2 .9 2 2 2zm0 2c-1.1 0-2 .9-2 2s.9 2 2 2 2-.9 2-2-.9-2-2-2zm0 6c-1.1 0-2 .9-2 2s.9 2 2 2 2-.9 2-2-.9-2-2-2z" }));
    }
}
SvgMoreVertical.defaultProps = {
    fillColor: '#3E4042',
    size: 24
};

class SvgPaper extends React.PureComponent {
    render() {
        return React.createElement("svg", { width: this.props.size, height: this.props.size, viewBox: "0 0 24 24" },
            React.createElement("path", { fill: this.props.fillColor, fillRule: "evenodd", d: "M6 2c-1.1 0-1.99.9-1.99 2L4 20c0 1.1.89 2 1.99 2H18c1.1 0 2-.9 2-2V8l-6-6H6zm7 7V3.5L18.5 9H13z" }));
    }
}
SvgPaper.defaultProps = {
    fillColor: '#3E4042',
    size: 24
};

class SvgPaper2 extends React.PureComponent {
    render() {
        return React.createElement("svg", { width: this.props.size, height: this.props.size, viewBox: "0 0 24 24" },
            React.createElement("path", { fill: this.props.fillColor, fillRule: "evenodd", d: "M14 2H6c-1.1 0-1.99.9-1.99 2L4 20c0 1.1.89 2 1.99 2H18c1.1 0 2-.9 2-2V8l-6-6zm2 16H8v-2h8v2zm0-4H8v-2h8v2zm-3-5V3.5L18.5 9H13z" }));
    }
}
SvgPaper2.defaultProps = {
    fillColor: '#3E4042',
    size: 24
};

class SvgPerson extends React.PureComponent {
    render() {
        return React.createElement("svg", { width: this.props.size, height: this.props.size, viewBox: "0 0 24 24" },
            React.createElement("path", { fill: this.props.fillColor, fillRule: "evenodd", d: "M12 12c2.762 0 5-2.238 5-5s-2.238-5-5-5-5 2.238-5 5 2.238 5 5 5zm-7 7.5V22h14v-2.5c0-2.992-2.622-5.5-7-5.5s-7 2.508-7 5.5z" }));
    }
}
SvgPerson.defaultProps = {
    fillColor: '#3E4042',
    size: 24
};

class SvgPersonOutline extends React.PureComponent {
    render() {
        return React.createElement("svg", { width: this.props.size, height: this.props.size, viewBox: "0 0 24 24" },
            React.createElement("path", { fill: this.props.fillColor, fillRule: "evenodd", d: "M18 21v-2c0-2.347-1.495-6-6-6s-6 3.653-6 6v2H4v-2c0-2.826 1.607-6.544 5.505-7.666A4.997 4.997 0 0 1 7 7c0-2.762 2.238-5 5-5 2.763 0 5 2.238 5 5a4.997 4.997 0 0 1-2.505 4.334C18.393 12.456 20 16.174 20 19v2h-2zm-6-11c1.658 0 3-1.342 3-3s-1.342-3-3-3-3 1.342-3 3 1.342 3 3 3z" }));
    }
}
SvgPersonOutline.defaultProps = {
    fillColor: '#3E4042',
    size: 24
};

class SvgPhone extends React.PureComponent {
    render() {
        return React.createElement("svg", { width: this.props.size, height: this.props.size, viewBox: "0 0 24 24" },
            React.createElement("path", { fill: this.props.fillColor, fillRule: "evenodd", d: "M4.338 11.411a4.572 4.572 0 0 1-.021-6.441L5.92 3.346a1.15 1.15 0 0 1 1.608-.017l3.06 2.969c.458.443.464 1.175.014 1.628l-2.704 2.703 5.547 5.404 2.654-2.6a1.141 1.141 0 0 1 1.607.01l2.959 2.959c.446.445.446 1.165.003 1.613l-1.619 1.628a4.57 4.57 0 0 1-6.47.009l-8.241-8.24z" }));
    }
}
SvgPhone.defaultProps = {
    fillColor: '#3E4042',
    size: 24
};

class SvgPhoto extends React.PureComponent {
    render() {
        return React.createElement("svg", { width: this.props.size, height: this.props.size, viewBox: "0 0 24 24" },
            React.createElement("path", { fill: this.props.fillColor, fillRule: "evenodd", d: "M4 3h16a1 1 0 0 1 1 1v16a1 1 0 0 1-1 1H4a1 1 0 0 1-1-1V4a1 1 0 0 1 1-1zm4.5 10.5l2.5 3.01L14.5 12l4.5 6H5l3.5-4.5z" }));
    }
}
SvgPhoto.defaultProps = {
    fillColor: '#3E4042',
    size: 24
};

class SvgPhotoAdd extends React.PureComponent {
    render() {
        return React.createElement("svg", { width: this.props.size, height: this.props.size, viewBox: "0 0 24 24" },
            React.createElement("path", { fill: this.props.fillColor, fillRule: "evenodd", d: "M21 14h-2V5H5v13h10v2H4c-.552 0-1-.423-1-.944V3.944C3 3.423 3.448 3 4 3h16c.552 0 1 .423 1 .944V14zM9 12.5l2 2.01L14.5 10l2.5 3v3H6l3-3.5zM19 18v-2h2v2h2v2h-2v2h-2v-2h-2v-2h2z" }));
    }
}
SvgPhotoAdd.defaultProps = {
    fillColor: '#3E4042',
    size: 24
};

class SvgPlay extends React.PureComponent {
    render() {
        return React.createElement("svg", { width: this.props.size, height: this.props.size, viewBox: "0 0 24 24" },
            React.createElement("path", { fill: this.props.fillColor, fillRule: "evenodd", d: "M5 19.29V4.71a1 1 0 0 1 1.49-.872l12.96 7.29a1 1 0 0 1 0 1.744l-12.96 7.29A1 1 0 0 1 5 19.29z" }));
    }
}
SvgPlay.defaultProps = {
    fillColor: '#3E4042',
    size: 24
};

class SvgPlayFast extends React.PureComponent {
    render() {
        return React.createElement("svg", { width: this.props.size, height: this.props.size, viewBox: "0 0 24 24" },
            React.createElement("path", { fill: this.props.fillColor, fillRule: "evenodd", d: "M11 14.667l-6.445 4.297A1 1 0 0 1 3 18.13V5.87a1 1 0 0 1 1.555-.833L11 9.333V5.87a1 1 0 0 1 1.555-.833l9.197 6.132a1 1 0 0 1 0 1.664l-9.197 6.132A1 1 0 0 1 11 18.13v-3.464z" }));
    }
}
SvgPlayFast.defaultProps = {
    fillColor: '#3E4042',
    size: 24
};

class SvgPlayForward extends React.PureComponent {
    render() {
        return React.createElement("svg", { width: this.props.size, height: this.props.size, viewBox: "0 0 24 24" },
            React.createElement("path", { fill: this.props.fillColor, fillRule: "evenodd", d: "M18.553 4.447L21 2v6h-6l2.135-2.135a8 8 0 1 0 1.735 10.236l1.71 1.038A9.995 9.995 0 0 1 12 22C6.477 22 2 17.523 2 12S6.477 2 12 2c2.507 0 4.798.922 6.553 2.447zM11.96 16c-1.697 0-2.854-1.022-2.902-2.416h1.508c.092.648.665 1.08 1.405 1.08.838 0 1.416-.561 1.416-1.41 0-.86-.583-1.432-1.41-1.432-.606 0-1.065.264-1.335.702H9.18L9.571 8h4.902v1.357h-3.638l-.173 2.005h.097c.33-.476.882-.762 1.655-.762 1.48 0 2.53 1.086 2.53 2.616 0 1.654-1.195 2.784-2.985 2.784z" }));
    }
}
SvgPlayForward.defaultProps = {
    fillColor: '#3E4042',
    size: 24
};

class SvgPlayOutline extends React.PureComponent {
    render() {
        return React.createElement("svg", { width: this.props.size, height: this.props.size, viewBox: "0 0 24 24" },
            React.createElement("path", { fill: this.props.fillColor, fillRule: "evenodd", d: "M17.42 12L7.5 6.42v11.16L17.42 12zM5.5 19.29V4.71a1 1 0 0 1 1.49-.872l12.96 7.29a1 1 0 0 1 0 1.744l-12.96 7.29a1 1 0 0 1-1.49-.872z" }));
    }
}
SvgPlayOutline.defaultProps = {
    fillColor: '#3E4042',
    size: 24
};

class SvgPlayPrevious extends React.PureComponent {
    render() {
        return React.createElement("svg", { width: this.props.size, height: this.props.size, viewBox: "0 0 24 24" },
            React.createElement("path", { fill: this.props.fillColor, fillRule: "evenodd", d: "M12 2c5.523 0 10 4.477 10 10s-4.477 10-10 10a9.995 9.995 0 0 1-8.58-4.861L5.13 16.1A8 8 0 1 0 6.865 5.865L9 8H3V2l2.447 2.447A9.961 9.961 0 0 1 12 2zm-.04 14c-1.698 0-2.855-1.022-2.903-2.416h1.508c.092.648.665 1.08 1.405 1.08.838 0 1.416-.561 1.416-1.41 0-.86-.583-1.432-1.41-1.432-.606 0-1.065.264-1.335.702H9.18L9.571 8h4.902v1.357h-3.638l-.173 2.005h.097c.33-.476.882-.762 1.655-.762 1.48 0 2.53 1.086 2.53 2.616 0 1.654-1.195 2.784-2.985 2.784z" }));
    }
}
SvgPlayPrevious.defaultProps = {
    fillColor: '#3E4042',
    size: 24
};

class SvgPlaySpeedX025 extends React.PureComponent {
    render() {
        return React.createElement("svg", { width: this.props.size, height: this.props.size, viewBox: "0 0 24 24" },
            React.createElement("path", { fill: this.props.fillColor, fillRule: "evenodd", d: "M2.514 11.486a9.904 9.904 0 0 1-.014-.404V9.213c0-1.363.247-2.406.74-3.13C3.736 5.362 4.445 5 5.369 5 6.292 5 7 5.358 7.495 6.074c.494.716.745 1.737.754 3.065v.612L6.5 11.5l-.18-.18V8.934c0-.78-.078-1.364-.232-1.754-.154-.39-.394-.584-.72-.584-.612 0-.929.714-.952 2.14v.847l-1.902 1.902zm8.13 2.87a.93.93 0 0 1-.285.46c-.1.09-.212.16-.335.208L10 15l.644-.644zm.337-.337L12 13l-.275-.275 1.934-2.458c.34-.471.59-.885.75-1.24a2.48 2.48 0 0 0 .242-1.023c0-.44-.076-.784-.228-1.033a.725.725 0 0 0-.656-.374c-.312 0-.56.145-.744.435-.183.29-.275.698-.275 1.223h-1.93c0-.607.126-1.162.377-1.665a2.817 2.817 0 0 1 1.06-1.172c.456-.279.971-.418 1.546-.418.884 0 1.57.244 2.056.73.487.488.73 1.18.73 2.077 0 .557-.134 1.122-.404 1.695s-.757 1.279-1.464 2.117l-1.271 1.815h3.364v1.597h-5.83v-1.012zm5.933-3.854l.49-5.03h4.79V6.78H18.98l-.177 2.12c.372-.248.754-.373 1.149-.373.815 0 1.444.29 1.885.87.442.58.663 1.4.663 2.46 0 .992-.263 1.792-.788 2.399-.526.607-1.228.91-2.107.91a2.93 2.93 0 0 1-1.448-.37 2.729 2.729 0 0 1-1.05-1.03 2.965 2.965 0 0 1-.39-1.495h1.903c.031.413.133.732.305.959a.8.8 0 0 0 .666.34c.318 0 .562-.153.734-.46.173-.305.259-.761.259-1.369 0-.57-.103-1-.31-1.29-.206-.29-.495-.436-.866-.436-.363 0-.643.125-.843.374l-.122.17-1.53-.394zM9.5 13l-2 2 2 2-1 1-2-2-2 2-1-1 2-2-2-2 1-1 2 2 2-2 1 1z" }));
    }
}
SvgPlaySpeedX025.defaultProps = {
    fillColor: '#3E4042',
    size: 24
};

class SvgPlaySpeedX05 extends React.PureComponent {
    render() {
        return React.createElement("svg", { width: this.props.size, height: this.props.size, viewBox: "0 0 24 24" },
            React.createElement("path", { fill: this.props.fillColor, fillRule: "evenodd", d: "M11.397 12.397l-2.206-2.206v-.668c0-.895-.088-1.567-.265-2.015-.177-.448-.453-.672-.828-.672-.703 0-1.068.82-1.094 2.46v1.7L6.5 11.5 4.8 9.8c.006-1.546.29-2.73.852-3.554C6.22 5.416 7.035 5 8.098 5c1.062 0 1.877.411 2.445 1.234.568.823.857 1.998.867 3.524v2.07c0 .195-.004.385-.013.569zm.24 3.01c0-.355.118-.647.355-.876.237-.229.546-.344.926-.344.37 0 .677.114.922.34.245.227.367.52.367.88 0 .364-.124.657-.371.878a1.326 1.326 0 0 1-.918.332c-.37 0-.676-.112-.918-.336-.242-.224-.363-.515-.363-.875zm3.14-4.47l.563-5.78h5.508v1.89h-3.696l-.203 2.437c.427-.286.867-.43 1.32-.43.938 0 1.66.334 2.169 1 .507.667.761 1.61.761 2.829 0 1.14-.302 2.06-.906 2.758-.604.698-1.411 1.046-2.422 1.046a3.367 3.367 0 0 1-1.664-.425A3.137 3.137 0 0 1 15 15.078c-.294-.505-.444-1.078-.45-1.719h2.188c.037.474.154.842.352 1.102a.92.92 0 0 0 .765.39c.365 0 .646-.175.844-.527.198-.351.297-.876.297-1.574 0-.656-.118-1.151-.355-1.484-.237-.334-.57-.5-.996-.5-.417 0-.74.143-.97.43l-.14.195-1.758-.454zM9.5 13l-2 2 2 2-1 1-2-2-2 2-1-1 2-2-2-2 1-1 2 2 2-2 1 1z" }));
    }
}
SvgPlaySpeedX05.defaultProps = {
    fillColor: '#3E4042',
    size: 24
};

class SvgPlaySpeedX1 extends React.PureComponent {
    render() {
        return React.createElement("svg", { width: this.props.size, height: this.props.size, viewBox: "0 0 24 24" },
            React.createElement("path", { fill: this.props.fillColor, fillRule: "evenodd", d: "M18.5 18.5H16V7.88L13 8.9V6.7L18 5h.5v13.5zm-9-5.5l-2 2 2 2-1 1-2-2-2 2-1-1 2-2-2-2 1-1 2 2 2-2 1 1z" }));
    }
}
SvgPlaySpeedX1.defaultProps = {
    fillColor: '#3E4042',
    size: 24
};

class SvgPlaySpeedX15 extends React.PureComponent {
    render() {
        return React.createElement("svg", { width: this.props.size, height: this.props.size, viewBox: "0 0 24 24" },
            React.createElement("path", { fill: this.props.fillColor, fillRule: "evenodd", d: "M7.45 10.55V7.704l-2.165.836V6.695L9.434 5h.234v5.668L8.5 9.5l-1.05 1.05zm4.187 4.716c0-.355.118-.646.355-.875.237-.23.546-.344.926-.344.37 0 .677.113.922.34.245.226.367.52.367.879 0 .364-.124.657-.371.879a1.326 1.326 0 0 1-.918.332c-.37 0-.676-.112-.918-.336-.242-.224-.363-.516-.363-.875zm3.14-4.47l.563-5.78h5.508v1.89h-3.696l-.203 2.438c.427-.287.867-.43 1.32-.43.938 0 1.66.333 2.169 1 .507.667.761 1.61.761 2.828 0 1.14-.302 2.06-.906 2.758-.604.698-1.411 1.047-2.422 1.047a3.367 3.367 0 0 1-1.664-.426A3.137 3.137 0 0 1 15 14.937c-.294-.505-.444-1.078-.45-1.718h2.188c.037.474.154.84.352 1.101a.92.92 0 0 0 .765.39c.365 0 .646-.175.844-.526.198-.352.297-.877.297-1.575 0-.656-.118-1.15-.355-1.484-.237-.333-.57-.5-.996-.5-.417 0-.74.143-.97.43l-.14.195-1.758-.453zM9.5 13l-2 2 2 2-1 1-2-2-2 2-1-1 2-2-2-2 1-1 2 2 2-2 1 1z" }));
    }
}
SvgPlaySpeedX15.defaultProps = {
    fillColor: '#3E4042',
    size: 24
};

class SvgPlaySpeedX2 extends React.PureComponent {
    render() {
        return React.createElement("svg", { width: this.props.size, height: this.props.size, viewBox: "0 0 24 24" },
            React.createElement("path", { fill: this.props.fillColor, fillRule: "evenodd", d: "M20.953 18.5h-8.79v-1.744l4.148-4.421c.57-.623.99-1.166 1.264-1.63.273-.464.41-.904.41-1.32 0-.57-.144-1.018-.432-1.344-.288-.326-.699-.489-1.233-.489-.576 0-1.03.198-1.36.595-.333.396-.498.917-.498 1.563h-2.555c0-.78.187-1.494.56-2.14.372-.646.9-1.153 1.58-1.52.682-.367 1.454-.55 2.317-.55 1.321 0 2.347.317 3.078.951.731.634 1.097 1.53 1.097 2.687 0 .634-.165 1.28-.493 1.937-.33.658-.893 1.424-1.692 2.299l-2.915 3.074h5.514V18.5zM9.5 13l-2 2 2 2-1 1-2-2-2 2-1-1 2-2-2-2 1-1 2 2 2-2 1 1z" }));
    }
}
SvgPlaySpeedX2.defaultProps = {
    fillColor: '#3E4042',
    size: 24
};

class SvgProject extends React.PureComponent {
    render() {
        return React.createElement("svg", { width: this.props.size, height: this.props.size, viewBox: "0 0 24 24" },
            React.createElement("path", { fill: this.props.fillColor, fillRule: "evenodd", d: "M19.382 15H12v-1h3a1 1 0 0 0 1-1V9h3.38l-1.275 2.552a1 1 0 0 0 0 .895L19.382 15zM4.692 6H14v6H6.026L4.692 6zm15.427 6l1.776-3.553A.998.998 0 0 0 21 7h-5V5a1 1 0 0 0-1-1H4.248l-.271-1.217a1.005 1.005 0 0 0-1.193-.76c-.54.12-.88.654-.76 1.194l4 18a1.002 1.002 0 0 0 1.193.759c.539-.12.879-.654.76-1.193L6.47 14H10v2a1 1 0 0 0 1 1h10a1 1 0 0 0 .895-1.448L20.119 12z" }));
    }
}
SvgProject.defaultProps = {
    fillColor: '#3E4042',
    size: 24
};

class SvgQuote extends React.PureComponent {
    render() {
        return React.createElement("svg", { width: this.props.size, height: this.props.size, viewBox: "0 0 24 24" },
            React.createElement("path", { fill: this.props.fillColor, fillRule: "evenodd", d: "M19 5h-2.667C14.111 8.805 13 11.805 13 14v.5a4.5 4.5 0 0 0 9 0 4.5 4.5 0 0 0-4.5-4.5H17l2-5zM8 5H5.333C3.111 8.805 2 11.805 2 14v.5a4.5 4.5 0 0 0 9 0A4.5 4.5 0 0 0 6.5 10H6l2-5z" }));
    }
}
SvgQuote.defaultProps = {
    fillColor: '#3E4042',
    size: 24
};

class SvgReceipt extends React.PureComponent {
    render() {
        return React.createElement("svg", { width: this.props.size, height: this.props.size, viewBox: "0 0 24 24" },
            React.createElement("defs", null,
                React.createElement("path", { id: "receipt_svg__a", d: "M19 2a1 1 0 0 1 1 1v18a1 1 0 0 1-1.555.832l-2.318-1.545-1.42 1.42A.993.993 0 0 1 14 22a.993.993 0 0 1-.707-.293L12 20.414l-1.293 1.293a.999.999 0 0 1-1.414 0l-1.42-1.42-2.318 1.545A1 1 0 0 1 4 21V3a1 1 0 0 1 1-1h14zm-1 17.132V4H6v15.132l1.445-.964a1 1 0 0 1 1.262.125L10 19.586l1.293-1.293a.997.997 0 0 1 1.414 0L14 19.586l1.293-1.293a.998.998 0 0 1 1.262-.125l1.445.964zM9 6h6a1 1 0 0 1 0 2H9a1 1 0 1 1 0-2zm0 4h6a1 1 0 0 1 0 2H9a1 1 0 0 1 0-2zm0 4h6a1 1 0 0 1 0 2H9a1 1 0 0 1 0-2z" })),
            React.createElement("use", { fill: this.props.fillColor, fillRule: "evenodd", xlinkHref: "#receipt_svg__a" }));
    }
}
SvgReceipt.defaultProps = {
    fillColor: '#3E4042',
    size: 24
};

class SvgReplay extends React.PureComponent {
    render() {
        return React.createElement("svg", { width: this.props.size, height: this.props.size, viewBox: "0 0 24 24" },
            React.createElement("path", { fill: this.props.fillColor, fillRule: "evenodd", d: "M17.02 5L12 10V6c-3.84.021-6.979 3.16-7 7-.014 3.847 3.153 7.014 7 7 3.847-.014 7.006-3.153 7.02-7H21c-.021 4.943-4.057 8.979-9 9-4.929.021-9.028-4.064-9-9 .028-4.936 4.064-8.972 9-9V0l5.02 5z" }));
    }
}
SvgReplay.defaultProps = {
    fillColor: '#3E4042',
    size: 24
};

class SvgReply extends React.PureComponent {
    render() {
        return React.createElement("svg", { width: this.props.size, height: this.props.size, viewBox: "0 0 24 24" },
            React.createElement("path", { fill: this.props.fillColor, fillRule: "evenodd", d: "M2.368 21.632l.594-5.347A9.964 9.964 0 0 1 2 12C2 6.477 6.477 2 12 2s10 4.477 10 10-4.477 10-10 10a9.964 9.964 0 0 1-4.285-.962l-5.347.594zm2.264-2.264l3.452-.384.268.138a8 8 0 1 0-3.474-3.474l.138.268-.384 3.452zM8 13a1 1 0 1 1 0-2 1 1 0 0 1 0 2zm4 0a1 1 0 1 1 0-2 1 1 0 0 1 0 2zm4 0a1 1 0 1 1 0-2 1 1 0 0 1 0 2z" }));
    }
}
SvgReply.defaultProps = {
    fillColor: '#3E4042',
    size: 24
};

class SvgReport extends React.PureComponent {
    render() {
        return React.createElement("svg", { width: this.props.size, height: this.props.size, viewBox: "0 0 24 24" },
            React.createElement("path", { fill: this.props.fillColor, fillRule: "evenodd", d: "M7 15h8v2H6v2h12v-2h-1v-4a5 5 0 0 0-10 0v2zm12 0h1v6H4v-6h1v-2a7 7 0 1 1 14 0v2zM12 0a1 1 0 0 1 1 1v2a1 1 0 0 1-2 0V1a1 1 0 0 1 1-1zm9.192 3.808a1 1 0 0 1 0 1.414l-1.414 1.414a1 1 0 0 1-1.414-1.414l1.414-1.414a1 1 0 0 1 1.414 0zm-18.384 0a1 1 0 0 1 1.414 0l1.414 1.414a1 1 0 0 1-1.414 1.414L2.808 5.222a1 1 0 0 1 0-1.414z" }));
    }
}
SvgReport.defaultProps = {
    fillColor: '#3E4042',
    size: 24
};

class SvgRotateClockwise extends React.PureComponent {
    render() {
        return React.createElement("svg", { width: this.props.size, height: this.props.size, viewBox: "0 0 24 24" },
            React.createElement("path", { fill: this.props.fillColor, fillRule: "evenodd", d: "M21 10.12h-6.78l2.74-2.82c-2.73-2.7-7.15-2.8-9.88-.1a6.875 6.875 0 0 0 0 9.79 7.02 7.02 0 0 0 9.88 0C18.32 15.65 19 14.08 19 12.1h2c0 1.98-.88 4.55-2.64 6.29-3.51 3.48-9.21 3.48-12.72 0-3.5-3.47-3.53-9.11-.02-12.58a8.987 8.987 0 0 1 12.65 0L21 3v7.12z" }));
    }
}
SvgRotateClockwise.defaultProps = {
    fillColor: '#3E4042',
    size: 24
};

class SvgSaveClass extends React.PureComponent {
    render() {
        return React.createElement("svg", { width: this.props.size, height: this.props.size, viewBox: "0 0 24 24" },
            React.createElement("path", { fill: this.props.fillColor, fillRule: "evenodd", d: "M21.893 9.65h-2.055c.107-.385.162-.767.162-1.15 0-2-1.5-3.5-3.5-3.5-1.54 0-3.04.99-3.56 2.36h-1.87C10.54 5.99 9.04 5 7.5 5 5.5 5 4 6.5 4 8.5c0 2.89 3.14 5.74 7.9 10.05l.1.1h2.968c-.487.445-.993.904-1.518 1.38L12 21.35l-1.45-1.31C5.4 15.36 2 12.28 2 8.5 2 5.42 4.42 3 7.5 3c1.74 0 3.41.81 4.5 2.09C13.09 3.81 14.76 3 16.5 3 19.58 3 22 5.42 22 8.5c0 .39-.036.772-.107 1.15zm-2.893 2v3h3v2h-3v3h-2v-3h-3v-2h3v-3h2z" }));
    }
}
SvgSaveClass.defaultProps = {
    fillColor: '#3E4042',
    size: 24
};

class SvgSearch extends React.PureComponent {
    render() {
        return React.createElement("svg", { width: this.props.size, height: this.props.size, viewBox: "0 0 24 24" },
            React.createElement("path", { fill: this.props.fillColor, fillRule: "evenodd", d: "M15.593 14.54L20.5 19 19 20.5l-4.46-4.907a6.5 6.5 0 1 1 1.054-1.054zM10.5 15a4.5 4.5 0 1 0 0-9 4.5 4.5 0 0 0 0 9z" }));
    }
}
SvgSearch.defaultProps = {
    fillColor: '#3E4042',
    size: 24
};

class SvgSearchLocation extends React.PureComponent {
    render() {
        return React.createElement("svg", { width: this.props.size, height: this.props.size, viewBox: "0 0 24 24" },
            React.createElement("path", { fill: this.props.fillColor, fillRule: "evenodd", d: "M4.537 12.75a7.502 7.502 0 0 0 6.713 6.713V17h1.5v2.463a7.502 7.502 0 0 0 6.713-6.713H17v-1.5h2.463a7.502 7.502 0 0 0-6.713-6.713V7h-1.5V4.537a7.502 7.502 0 0 0-6.713 6.713H7v1.5H4.537zM12 21a9 9 0 1 1 0-18 9 9 0 0 1 0 18z" }));
    }
}
SvgSearchLocation.defaultProps = {
    fillColor: '#3E4042',
    size: 24
};

class SvgSend extends React.PureComponent {
    render() {
        return React.createElement("svg", { width: this.props.size, height: this.props.size, viewBox: "0 0 24 24" },
            React.createElement("path", { fill: this.props.fillColor, fillRule: "evenodd", d: "M14 9V5l7 7-7 7v-4.1c-5 0-8.5 1.6-11 5.1 1-5 4-10 11-11z" }));
    }
}
SvgSend.defaultProps = {
    fillColor: '#3E4042',
    size: 24
};

class SvgShareApple extends React.PureComponent {
    render() {
        return React.createElement("svg", { width: this.props.size, height: this.props.size, viewBox: "0 0 24 24" },
            React.createElement("path", { fill: this.props.fillColor, fillRule: "evenodd", d: "M19 19v-6h2v7a1 1 0 0 1-1 1H4a1 1 0 0 1-1-1v-7h2v6h14zM13 6.829l3.586 3.587L18 9 12 3 6 9.001l1.414 1.415L11 6.829V15h2V6.83z" }));
    }
}
SvgShareApple.defaultProps = {
    fillColor: '#3E4042',
    size: 24
};

class SvgSheild extends React.PureComponent {
    render() {
        return React.createElement("svg", { width: this.props.size, height: this.props.size, viewBox: "0 0 24 24" },
            React.createElement("path", { fill: this.props.fillColor, fillRule: "evenodd", d: "M12 18c-3.307 0-6-2.693-6-6s2.693-6 6-6 6 2.693 6 6-2.693 6-6 6m.073-16.5h-.146C9.729 3.337 6.549 4.5 3 4.5V12c0 7.524 9 10.5 9 10.5s9-3 9-10.5V4.5c-3.549 0-6.729-1.163-8.927-3m.426 10.754l.251 1.996h-1.5l.25-1.996a1.124 1.124 0 0 1-.625-1.004 1.125 1.125 0 0 1 2.25 0c0 .441-.257.818-.626 1.004M12 7.5a4.5 4.5 0 1 0 0 9 4.5 4.5 0 0 0 0-9" }));
    }
}
SvgSheild.defaultProps = {
    fillColor: '#3E4042',
    size: 24
};

class SvgShippingTruck extends React.PureComponent {
    render() {
        return React.createElement("svg", { width: this.props.size, height: this.props.size, viewBox: "0 0 24 24" },
            React.createElement("path", { fill: this.props.fillColor, fillRule: "evenodd", d: "M4 17H3a1 1 0 0 1-1-1V5a1 1 0 0 1 1-1h11a1 1 0 0 1 1 1v1h4l3 4v6a1 1 0 0 1-1 1h-1c0 1.66-1.34 3-3 3s-3-1.34-3-3h-4c0 1.66-1.34 3-3 3s-3-1.34-3-3zm5.238-2H13V6H4v9h.762c.549-.614 1.347-1 2.238-1 .89 0 1.69.386 2.238 1zM18 8h-3v4h5v-1.5L18 8zm-1 10c.553 0 1-.447 1-1 0-.553-.447-1-1-1-.553 0-1 .447-1 1 0 .553.447 1 1 1zM7 18c.553 0 1-.447 1-1 0-.553-.447-1-1-1-.553 0-1 .447-1 1 0 .553.447 1 1 1z" }));
    }
}
SvgShippingTruck.defaultProps = {
    fillColor: '#3E4042',
    size: 24
};

class SvgStopPlay extends React.PureComponent {
    render() {
        return React.createElement("svg", { width: this.props.size, height: this.props.size, viewBox: "0 0 24 24" },
            React.createElement("path", { fill: this.props.fillColor, fillRule: "evenodd", d: "M6 3h4v18H6V3zm8 0h4v18h-4V3z" }));
    }
}
SvgStopPlay.defaultProps = {
    fillColor: '#3E4042',
    size: 24
};

class SvgStore extends React.PureComponent {
    render() {
        return React.createElement("svg", { width: this.props.size, height: this.props.size, viewBox: "0 0 24 24" },
            React.createElement("path", { fill: this.props.fillColor, fillRule: "evenodd", d: "M4.387 8h15.226l-1.334-4H5.721L4.387 8zM20 10H4a2 2 0 1 0 4 0h2a2 2 0 1 0 4 0h2a2 2 0 1 0 4 0zM6 14v6h12v-6a3.99 3.99 0 0 1-3-1.354A3.99 3.99 0 0 1 12 14a3.99 3.99 0 0 1-3-1.354A3.99 3.99 0 0 1 6 14zm14-.535v7.82c0 .395-.448.715-1 .715H5c-.552 0-1-.32-1-.714v-7.821A3.998 3.998 0 0 1 2 10V9a1 1 0 0 1 .051-.316l2-6A1 1 0 0 1 5 2h14a1 1 0 0 1 .949.684l2 6A1 1 0 0 1 22 9v1c0 1.48-.804 2.773-2 3.465z" }));
    }
}
SvgStore.defaultProps = {
    fillColor: '#3E4042',
    size: 24
};

class SvgTalkHelp extends React.PureComponent {
    render() {
        return React.createElement("svg", { width: this.props.size, height: this.props.size, viewBox: "0 0 24 24" },
            React.createElement("path", { fill: this.props.fillColor, fillRule: "evenodd", d: "M2.368 21.632l.594-5.347A9.964 9.964 0 0 1 2 12C2 6.477 6.477 2 12 2s10 4.477 10 10-4.477 10-10 10a9.964 9.964 0 0 1-4.285-.962l-5.347.594zm2.264-2.264l3.452-.384.268.138a8 8 0 1 0-3.474-3.474l.138.268-.384 3.452zM11 18h2v-2h-2v2zm1-12c-2.21 0-4 1.79-4 4h2c0-1.1.9-2 2-2s2 .9 2 2c0 2-3 1.75-3 5h2c0-2.25 3-2.5 3-5 0-2.21-1.79-4-4-4z" }));
    }
}
SvgTalkHelp.defaultProps = {
    fillColor: '#3E4042',
    size: 24
};

class SvgTalkHelp2 extends React.PureComponent {
    render() {
        return React.createElement("svg", { width: this.props.size, height: this.props.size, viewBox: "0 0 24 24" },
            React.createElement("path", { fill: this.props.fillColor, fillRule: "evenodd", d: "M21.632 21.632l-5.347-.594A9.964 9.964 0 0 1 12 22C6.477 22 2 17.523 2 12S6.477 2 12 2s10 4.477 10 10a9.964 9.964 0 0 1-.962 4.285l.594 5.347zm-2.264-2.264l-.384-3.452.138-.268a8 8 0 1 0-3.474 3.474l.268-.138 3.452.384zM11 18h2v-2h-2v2zm1-12c-2.21 0-4 1.79-4 4h2c0-1.1.9-2 2-2s2 .9 2 2c0 2-3 1.75-3 5h2c0-2.25 3-2.5 3-5 0-2.21-1.79-4-4-4z" }));
    }
}
SvgTalkHelp2.defaultProps = {
    fillColor: '#3E4042',
    size: 24
};

class SvgThunder extends React.PureComponent {
    render() {
        return React.createElement("svg", { width: this.props.size, height: this.props.size, viewBox: "0 0 24 24" },
            React.createElement("defs", null,
                React.createElement("path", { id: "thunder_svg__a", d: "M18 10a1 1 0 0 1 .774 1.633l-9 11c-.667.816-1.979.178-1.75-.85L9.754 14H6a1 1 0 0 1-.774-1.633l9-11c.667-.816 1.979-.178 1.75.85L14.246 10H18z" })),
            React.createElement("use", { fill: this.props.fillColor, fillRule: "evenodd", xlinkHref: "#thunder_svg__a" }));
    }
}
SvgThunder.defaultProps = {
    fillColor: '#3E4042',
    size: 24
};

class SvgTimer extends React.PureComponent {
    render() {
        return React.createElement("svg", { width: this.props.size, height: this.props.size, viewBox: "0 0 24 24" },
            React.createElement("path", { fill: this.props.fillColor, fillRule: "evenodd", d: "M22 5.72l-4.6-3.86-1.29 1.53 4.6 3.86L22 5.72zM7.88 3.39L6.6 1.86 2 5.71l1.29 1.53 4.59-3.85zM12.5 8H11v6l4.75 2.85.75-1.23-4-2.37V8zM12 4.5A8.5 8.5 0 0 0 3.5 13c0 4.694 3.797 8.5 8.5 8.5a8.5 8.5 0 0 0 0-17z" }));
    }
}
SvgTimer.defaultProps = {
    fillColor: '#3E4042',
    size: 24
};

class SvgTimerOutline extends React.PureComponent {
    render() {
        return React.createElement("svg", { width: this.props.size, height: this.props.size, viewBox: "0 0 24 24" },
            React.createElement("path", { fill: this.props.fillColor, fillRule: "evenodd", d: "M22 5.72l-4.6-3.86-1.29 1.53 4.6 3.86L22 5.72zM7.88 3.39L6.6 1.86 2 5.71l1.29 1.53 4.59-3.85zM12.5 8H11v6l4.75 2.85.75-1.23-4-2.37V8zM12 4a9 9 0 0 0-9 9c0 4.97 4.02 9 9 9a9 9 0 0 0 0-18zm0 16c-3.87 0-7-3.13-7-7s3.13-7 7-7 7 3.13 7 7-3.13 7-7 7z" }));
    }
}
SvgTimerOutline.defaultProps = {
    fillColor: '#3E4042',
    size: 24
};

class SvgToggleOff extends React.PureComponent {
    render() {
        return React.createElement("svg", { width: this.props.size, height: this.props.size, viewBox: "0 0 24 24" },
            React.createElement("path", { fill: this.props.fillColor, fillRule: "evenodd", d: "M20 12a8 8 0 1 0-16 0 8 8 0 0 0 16 0zM2 12C2 6.477 6.477 2 12 2s10 4.477 10 10-4.477 10-10 10S2 17.523 2 12z" }));
    }
}
SvgToggleOff.defaultProps = {
    fillColor: '#3E4042',
    size: 24
};

class SvgToggleOn extends React.PureComponent {
    render() {
        return React.createElement("svg", { width: this.props.size, height: this.props.size, viewBox: "0 0 24 24" },
            React.createElement("defs", null,
                React.createElement("path", { id: "toggle-on_svg__a", d: "M2 12C2 6.477 6.477 2 12 2s10 4.477 10 10-4.477 10-10 10S2 17.523 2 12z" })),
            React.createElement("g", { fill: "none", fillRule: "evenodd" },
                React.createElement("mask", { id: "toggle-on_svg__b", fill: "#fff" },
                    React.createElement("use", { xlinkHref: "#toggle-on_svg__a" })),
                React.createElement("use", { fill: this.props.fillColor, xlinkHref: "#toggle-on_svg__a" }),
                React.createElement("circle", { cx: 12, cy: 12, r: 4, fill: "#FFF", mask: "url(#toggle-on_svg__b)" })));
    }
}
SvgToggleOn.defaultProps = {
    fillColor: '#3E4042',
    size: 24
};

class SvgTrash extends React.PureComponent {
    render() {
        return React.createElement("svg", { width: this.props.size, height: this.props.size, viewBox: "0 0 24 24" },
            React.createElement("path", { fill: this.props.fillColor, fillRule: "evenodd", d: "M8 5V3.999A2 2 0 0 1 9.99 2h4.02C15.11 2 16 2.893 16 3.999V5h4.1c.6 0 .9.333.9 1s-.3 1-.9 1H3.9C3.3 7 3 6.667 3 6s.3-1 .9-1H8zm2 0h4V4h-4v1zM5 8h2v11.008c0 .547.448.992 1.006.992h7.988A1 1 0 0 0 17 19.008V8h2v11.008A3 3 0 0 1 15.994 22H8.006A2.998 2.998 0 0 1 5 19.008V8zm4 2.872c0-.481.444-.872 1-.872.552 0 1 .396 1 .872v5.256c0 .481-.444.872-1 .872-.552 0-1-.396-1-.872v-5.256zm4 0c0-.481.444-.872 1-.872.552 0 1 .396 1 .872v5.256c0 .481-.444.872-1 .872-.552 0-1-.396-1-.872v-5.256z" }));
    }
}
SvgTrash.defaultProps = {
    fillColor: '#3E4042',
    size: 24
};

class SvgUndo extends React.PureComponent {
    render() {
        return React.createElement("svg", { width: this.props.size, height: this.props.size, viewBox: "0 0 24 24" },
            React.createElement("path", { fill: this.props.fillColor, fillRule: "evenodd", d: "M6.829 10l3.587 3.586L9 15 3 9l6.001-6 1.415 1.414L6.829 8H15A6 6 0 0 1 15 20h-3v-2h3a4 4 0 0 0 0-8H6.829z" }));
    }
}
SvgUndo.defaultProps = {
    fillColor: '#3E4042',
    size: 24
};

class SvgVolume extends React.PureComponent {
    render() {
        return React.createElement("svg", { width: this.props.size, height: this.props.size, viewBox: "0 0 24 24" },
            React.createElement("path", { fill: this.props.fillColor, fillRule: "evenodd", d: "M5 14v8h4a2 2 0 0 1 1.11.336L16 26.263V9.737l-5.89 3.927A2 2 0 0 1 9 14H5zm-2-.504C3 12.67 3.665 12 4.514 12H9l7.445-4.964A1 1 0 0 1 18 7.87V28.13a1 1 0 0 1-1.555.833L9 24H4.514C3.678 24 3 23.32 3 22.504v-9.008zm18.9-.696a1 1 0 1 1 1.2-1.6c.449.337 1.081.942 1.709 1.806C25.862 14.454 26.5 16.128 26.5 18c0 1.872-.638 3.546-1.691 4.994-.628.864-1.26 1.47-1.709 1.806a1 1 0 0 1-1.2-1.6c.063-.047.196-.16.377-.332.31-.298.623-.65.914-1.05.822-1.13 1.309-2.408 1.309-3.818 0-1.41-.487-2.688-1.309-3.818a7.872 7.872 0 0 0-.914-1.05 4.734 4.734 0 0 0-.377-.332zm1.013 18.153a1 1 0 1 1-.606-1.906C26.875 27.593 30.5 22.8 30.5 18c0-4.769-3.642-9.574-8.198-11.049a1 1 0 1 1 .616-1.902C28.285 6.786 32.5 12.348 32.5 18c0 5.685-4.2 11.238-9.587 12.953z" }));
    }
}
SvgVolume.defaultProps = {
    fillColor: '#3E4042',
    size: 24
};

class SvgWeb extends React.PureComponent {
    render() {
        return React.createElement("svg", { width: this.props.size, height: this.props.size, viewBox: "0 0 24 24" },
            React.createElement("path", { fill: this.props.fillColor, fillRule: "evenodd", d: "M4.054 13c.2 1.792.954 3.321 2.29 4.657.888.889 1.863 1.52 2.943 1.901a9.636 9.636 0 0 1-.48-.43c-1.56-1.5-2.565-3.53-2.769-6.128H4.054zm0-2H6.04c.204-2.594 1.21-4.624 2.768-6.12.165-.159.33-.306.493-.443-1.086.381-2.065 1.014-2.957 1.906C5.008 7.68 4.254 9.208 4.054 11zM11 11V5.657a6.852 6.852 0 0 0-.807.665C9.01 7.457 8.237 8.983 8.046 11H11zm0 2H8.045c.19 2.02.965 3.548 2.148 4.685.26.25.532.471.807.665V13zm8.946 0h-1.984c-.204 2.597-1.209 4.629-2.77 6.127-.16.154-.32.298-.48.431 1.081-.381 2.056-1.012 2.945-1.901 1.335-1.336 2.089-2.865 2.289-4.657zm0-2c-.2-1.792-.954-3.321-2.29-4.657-.891-.892-1.87-1.525-2.956-1.906.163.137.328.284.493.442C16.752 6.376 17.757 8.406 17.96 11h1.985zM13 11h2.954c-.19-2.017-.965-3.543-2.147-4.678A6.852 6.852 0 0 0 13 5.657V11zm0 2v5.35c.275-.194.546-.415.807-.665 1.183-1.137 1.958-2.665 2.148-4.685H13zm8.956 0c-.21 2.335-1.172 4.358-2.885 6.071-1.713 1.713-3.736 2.674-6.071 2.885v.05h-2v-.05c-2.335-.21-4.358-1.172-6.071-2.885C3.216 17.358 2.255 15.335 2.044 13H2v-.998a11.722 11.722 0 0 1 0-.004V11h.044c.21-2.335 1.172-4.358 2.885-6.071C6.642 3.216 8.665 2.255 11 2.044V2h2v.044c2.335.21 4.358 1.172 6.071 2.885 1.713 1.713 2.674 3.736 2.885 6.071H22v2h-.044z" }));
    }
}
SvgWeb.defaultProps = {
    fillColor: '#3E4042',
    size: 24
};

class SvgWon extends React.PureComponent {
    render() {
        return React.createElement("svg", { width: this.props.size, height: this.props.size, viewBox: "0 0 24 24" },
            React.createElement("path", { fill: this.props.fillColor, fillRule: "evenodd", d: "M6.107 10.071L5.25 6.214h1.607l1.929 9 1.928-9h2.572l1.928 9 1.929-9h1.607l-.857 3.857h1.821v1.286h-2.107l-1.428 6.429H14.25L12 8.143l-2.25 9.643H7.821l-1.428-6.429H4.286v-1.286h1.821z" }));
    }
}
SvgWon.defaultProps = {
    fillColor: '#3E4042',
    size: 24
};

class SvgWonCricle extends React.PureComponent {
    render() {
        return React.createElement("svg", { width: this.props.size, height: this.props.size, viewBox: "0 0 24 24" },
            React.createElement("path", { fill: this.props.fillColor, fillRule: "evenodd", d: "M8.071 11.357L7.5 8.786h1.071l1.286 6 1.286-6h1.714l1.286 6 1.286-6H16.5l-.571 2.571h1.214v1.286h-1.5l-.857 3.857H13.5L12 10.071 10.5 16.5H9.214l-.857-3.857h-1.5v-1.286h1.214zM12 22C6.477 22 2 17.523 2 12S6.477 2 12 2s10 4.477 10 10-4.477 10-10 10zm0-2a8 8 0 1 0 0-16 8 8 0 0 0 0 16z" }));
    }
}
SvgWonCricle.defaultProps = {
    fillColor: '#3E4042',
    size: 24
};



var index$2 = /*#__PURE__*/Object.freeze({
  Add: SvgAdd,
  AddCircleOutline: SvgAddCircleOutline,
  Alert: SvgAlert,
  Arrow: SvgArrow,
  Bell: SvgBell,
  BellOff: SvgBellOff,
  Bookmark: SvgBookmark,
  Bright: SvgBright,
  Camera: SvgCamera,
  Category: SvgCategory,
  Check: SvgCheck,
  CheckCircle: SvgCheckCircle,
  CheckCircleOutline: SvgCheckCircleOutline,
  CheckboxIndeterminated: SvgCheckboxIndeterminated,
  CheckboxOff: SvgCheckboxOff,
  CheckboxOn: SvgCheckboxOn,
  Chevron: SvgChevron,
  ChevronDown: SvgChevronDown,
  Clock: SvgClock,
  Close: SvgClose,
  CloseCircle: SvgCloseCircle,
  Comment: SvgComment,
  Compass: SvgCompass,
  Confetti: SvgConfetti,
  Contents: SvgContents,
  Coupon: SvgCoupon,
  CreditCard: SvgCreditCard,
  Crop: SvgCrop,
  Crown: SvgCrown,
  DepositPassbook: SvgDepositPassbook,
  Download: SvgDownload,
  DropDown: SvgDropDown,
  Earybird: SvgEarybird,
  Edit: SvgEdit,
  EditBody: SvgEditBody,
  EditBold: SvgEditBold,
  EditBullet: SvgEditBullet,
  EditNumber: SvgEditNumber,
  EditOutline: SvgEditOutline,
  Eye: SvgEye,
  FullScreen: SvgFullScreen,
  FullScreenExit: SvgFullScreenExit,
  Gear: SvgGear,
  Gift: SvgGift,
  Groove: SvgGroove,
  Heart: SvgHeart,
  HeartOutline: SvgHeartOutline,
  Help: SvgHelp,
  Home: SvgHome,
  Info: SvgInfo,
  Leaf: SvgLeaf,
  LeesonTime: SvgLeesonTime,
  Like: SvgLike,
  LikeOutline: SvgLikeOutline,
  Link: SvgLink,
  Location: SvgLocation,
  Lock: SvgLock,
  LockOutline: SvgLockOutline,
  LockOutlineOff: SvgLockOutlineOff,
  Logout: SvgLogout,
  Menu: SvgMenu,
  Message: SvgMessage,
  MessageOutline: SvgMessageOutline,
  Minus: SvgMinus,
  MinusCircle: SvgMinusCircle,
  MoreHorizontal: SvgMoreHorizontal,
  MoreVertical: SvgMoreVertical,
  Paper: SvgPaper,
  Paper2: SvgPaper2,
  Person: SvgPerson,
  PersonOutline: SvgPersonOutline,
  Phone: SvgPhone,
  Photo: SvgPhoto,
  PhotoAdd: SvgPhotoAdd,
  Play: SvgPlay,
  PlayFast: SvgPlayFast,
  PlayForward: SvgPlayForward,
  PlayOutline: SvgPlayOutline,
  PlayPrevious: SvgPlayPrevious,
  PlaySpeedX025: SvgPlaySpeedX025,
  PlaySpeedX05: SvgPlaySpeedX05,
  PlaySpeedX1: SvgPlaySpeedX1,
  PlaySpeedX15: SvgPlaySpeedX15,
  PlaySpeedX2: SvgPlaySpeedX2,
  Project: SvgProject,
  Quote: SvgQuote,
  Receipt: SvgReceipt,
  Replay: SvgReplay,
  Reply: SvgReply,
  Report: SvgReport,
  RotateClockwise: SvgRotateClockwise,
  SaveClass: SvgSaveClass,
  Search: SvgSearch,
  SearchLocation: SvgSearchLocation,
  Send: SvgSend,
  ShareApple: SvgShareApple,
  Sheild: SvgSheild,
  ShippingTruck: SvgShippingTruck,
  StopPlay: SvgStopPlay,
  Store: SvgStore,
  TalkHelp: SvgTalkHelp,
  TalkHelp2: SvgTalkHelp2,
  Thunder: SvgThunder,
  Timer: SvgTimer,
  TimerOutline: SvgTimerOutline,
  ToggleOff: SvgToggleOff,
  ToggleOn: SvgToggleOn,
  Trash: SvgTrash,
  Undo: SvgUndo,
  Volume: SvgVolume,
  Web: SvgWeb,
  Won: SvgWon,
  WonCricle: SvgWonCricle
});

const heading1BlackBold = styled.css `
  font-family: 'NanumSquare';
  font-size: 32px;
  color: ${gray800};
  line-height: 44px;
  font-weight: bold;
`;
const heading2WhiteBold = styled.css `
  font-family: 'NanumSquare';
  font-size: 24px;
  color: ${white};
  line-height: 34px;
  font-weight: bold;
`;
const heading1WhiteBold = styled.css `
  font-family: 'NanumSquare';
  font-size: 32px;
  line-height: 44px;
  font-weight: bold;
  color: ${white};
`;
const body1Black = styled.css `
  font-size: 16px;
  color: ${gray800};
  line-height: 24px;
`;
const body2Black = styled.css `
  font-size: 14px;
  color: ${gray800};
  line-height: 20px;
`;
const body2White = styled.css `
  font-size: 14px;
  color: ${white};
  line-height: 20px;
`;
const body2Gray = styled.css `
  font-size: 14px;
  color: ${gray500};
  line-height: 20px;
`;
const tiny1WhiteBold = styled.css `
  color: ${white};
  font-size: 11px;
  font-weight: bold;
  line-height: 16px;
`;
const body1WhiteBold = styled.css `
  font-size: 16px;
  font-weight: bold;
  color: ${white};
  line-height: 24px;
`;
const body2BlackBold = styled.css `
  font-size: 14px;
  font-weight: bold;
  color: ${gray800};
  line-height: 20px;
`;
const subheadingBlackBold = styled.css `
  font-size: 20px;
  font-weight: bold;
  color: ${gray800};
  line-height: 32px;
`;
const tiny1Black = styled.css `
  font-size: 11px;
  line-height: 16px;
  color: ${gray800};
`;
const tiny2Black = styled.css `
  font-size: 9px;
  line-height: 12px;
`;
const tiny2White = styled.css `
  font-size: 9px;
  line-height: 12px;
  color: ${white};
`;
const body1Body = styled.css `
  font-size: 16px;
  font-weight: 300;
  color: ${gray700};
  line-height: 28px;
`;
const heading3BlackBold = styled.css `
  font-family: 'NanumSquare';
  font-size: 18px;
  color: ${gray800};
  line-height: 28px;
  font-weight: bold;
`;
const tiny1Gray = styled.css `
  font-size: 11px;
  color: ${gray600};
  line-height: 16px;
`;
const heading2BlackExtraBold = styled.css `
  font-family: 'NanumSquare';
  font-size: 24px;
  color: ${gray800};
  line-height: 34px;
  font-weight: 800;
`;
const tiny1White = styled.css `
  font-size: 11px;
  line-height: 16px;
  color: ${white};
`;
const heading3WhiteBold = styled.css `
  font-family: 'NanumSquare';
  font-size: 18px;
  color: ${white};
  line-height: 28px;
  font-weight: bold;
`;
const body1Gray = styled.css `
  font-size: 16px;
  color: ${gray500};
  line-height: 24px;
`;
const body2WhiteBold = styled.css `
  font-size: 14px;
  font-weight: bold;
  color: ${white};
  line-height: 20px;
`;
const body1BlackBold = styled.css `
  font-size: 16px;
  font-weight: bold;
  color: ${gray800};
  line-height: 24px;
`;
const subheadingGray = styled.css `
  font-size: 20px;
  color: ${gray500};
  line-height: 32px;
`;
const tiny2Gray = styled.css `
  font-size: 9px;
  color: ${gray600};
  line-height: 12px;
`;
const heading1BlackExtraBold = styled.css `
  font-family: 'NanumSquare';
  font-size: 32px;
  color: ${gray800};
  line-height: 44px;
  font-weight: 800;
`;
const heading3BlackExtraBold = styled.css `
  font-family: 'NanumSquare';
  font-size: 18px;
  color: ${gray800};
  line-height: 28px;
  font-weight: 800;
`;
const subheadingWhiteBold = styled.css `
  font-size: 20px;
  font-weight: bold;
  color: ${white};
  line-height: 32px;
`;
const tiny1BlackBold = styled.css `
  font-size: 11px;
  font-weight: bold;
  color: ${gray800};
  line-height: 16px;
`;
const body1White = styled.css `
  font-size: 16px;
  color: ${white};
  line-height: 24px;
`;
const body1Paragraph = styled.css `
  font-size: 16px;
  line-height: 28px;
  color: ${gray600};
`;
const body2Body = styled.css `
  font-size: 14px;
  font-weight: 300;
  color: ${gray800};
  line-height: 24px;
`;
const body2Paragraph = styled.css `
  font-size: 14px;
  font-weight: 300;
  line-height: 24px;
  color: ${gray700};
`;
const heading3WhiteExtraBold = styled.css `
  font-family: 'NanumSquare';
  font-size: 18px;
  color: ${white};
  line-height: 28px;
  font-weight: 800;
`;
const heading2BlackBold = styled.css `
  font-family: 'NanumSquare';
  font-size: 24px;
  color: ${gray800};
  line-height: 34px;
  font-weight: bold;
`;
const tiny2WhiteBold = styled.css `
  font-size: 9px;
  font-weight: bold;
  color: ${white};
  line-height: 12px;
`;
const heading1WhiteExtraBold = styled.css `
  font-family: 'NanumSquare';
  font-size: 32px;
  color: ${white};
  line-height: 44px;
  font-weight: 800;
`;
const body2GrayBold = styled.css `
  font-size: 14px;
  font-weight: bold;
  color: ${gray500};
  line-height: 20px;
`;
const heading3GrayBold = styled.css `
  font-family: 'NanumSquare';
  font-size: 18px;
  color: ${gray500};
  line-height: 28px;
  font-weight: bold;
`;
const subheadingBlack = styled.css `
  font-size: 20px;
  color: ${gray700};
  line-height: 32px;
`;
const display2 = styled.css `
  font-family: 'NanumSquare';
  font-size: 96px;
  font-weight: ${props => props.fontWeight || 'normal'};
  line-height: 108px;
  letter-spacing: -2px;
  margin: 0;
`;
const display3 = styled.css `
  font-family: 'NanumSquare';
  font-size: 72px;
  font-weight: ${props => props.fontWeight || 'normal'};
  line-height: 86px;
  letter-spacing: -1.5px;
  margin: 0;
`;
const headline1 = styled.css `
  font-family: 'NanumSquare';
  font-size: 48px;
  font-weight: ${props => props.fontWeight || 'bold'};
  line-height: 56px;
  letter-spacing: -1px;
  margin: 0;
`;
const headline2 = styled.css `
  font-family: 'NanumSquare';
  font-size: 32px;
  font-weight: ${props => props.fontWeight || 'bold'};
  line-height: 40px;
  letter-spacing: -0.6px;
  margin: 0;
`;
const headline3 = styled.css `
  font-family: 'NanumSquare';
  font-size: 24px;
  font-weight: ${props => props.fontWeight || 'bold'};
  line-height: 32px;
  letter-spacing: -0.4px;
  margin: 0;
`;
const subtitle1 = styled.css `
  font-family: 'SpoqaHanSans';
  font-size: 20px;
  font-weight: ${props => props.fontWeight || 'bold'};
  line-height: 28px;
  letter-spacing: -0.2px;
  margin: 0;
`;
const body1 = styled.css `
  font-family: 'SpoqaHanSans';
  font-size: 16px;
  font-weight: ${props => props.fontWeight || 'normal'};
  line-height: 24px;
  letter-spacing: -0.1px;
  margin: 0;
`;
const body2 = styled.css `
  font-family: 'SpoqaHanSans';
  font-size: 14px;
  font-weight: ${props => props.fontWeight || 'normal'};
  line-height: 20px;
  letter-spacing: normal;
  margin: 0;
`;
const caption1 = styled.css `
  font-family: 'SpoqaHanSans';
  font-size: 11px;
  font-weight: ${props => props.fontWeight || 'normal'};
  line-height: 16px;
  letter-spacing: normal;
  margin: 0;
`;
const caption2 = styled.css `
  font-family: 'SpoqaHanSans';
  font-size: 9px;
  font-weight: ${props => props.fontWeight || 'normal'};
  line-height: 12px;
  letter-spacing: normal;
  margin: 0;
`;
const tiny1 = styled.css `
  font-family: 'SpoqaHanSans';
  font-size: 11px;
  font-weight: ${props => props.fontWeight || 'normal'};
  line-height: 16px;
  letter-spacing: normal;
  margin: 0;
`;

var index$3 = /*#__PURE__*/Object.freeze({
  heading1BlackBold: heading1BlackBold,
  heading2WhiteBold: heading2WhiteBold,
  heading1WhiteBold: heading1WhiteBold,
  body1Black: body1Black,
  body2Black: body2Black,
  body2White: body2White,
  body2Gray: body2Gray,
  tiny1WhiteBold: tiny1WhiteBold,
  body1WhiteBold: body1WhiteBold,
  body2BlackBold: body2BlackBold,
  subheadingBlackBold: subheadingBlackBold,
  tiny1Black: tiny1Black,
  tiny2Black: tiny2Black,
  tiny2White: tiny2White,
  body1Body: body1Body,
  heading3BlackBold: heading3BlackBold,
  tiny1Gray: tiny1Gray,
  heading2BlackExtraBold: heading2BlackExtraBold,
  tiny1White: tiny1White,
  heading3WhiteBold: heading3WhiteBold,
  body1Gray: body1Gray,
  body2WhiteBold: body2WhiteBold,
  body1BlackBold: body1BlackBold,
  subheadingGray: subheadingGray,
  tiny2Gray: tiny2Gray,
  heading1BlackExtraBold: heading1BlackExtraBold,
  heading3BlackExtraBold: heading3BlackExtraBold,
  subheadingWhiteBold: subheadingWhiteBold,
  tiny1BlackBold: tiny1BlackBold,
  body1White: body1White,
  body1Paragraph: body1Paragraph,
  body2Body: body2Body,
  body2Paragraph: body2Paragraph,
  heading3WhiteExtraBold: heading3WhiteExtraBold,
  heading2BlackBold: heading2BlackBold,
  tiny2WhiteBold: tiny2WhiteBold,
  heading1WhiteExtraBold: heading1WhiteExtraBold,
  body2GrayBold: body2GrayBold,
  heading3GrayBold: heading3GrayBold,
  subheadingBlack: subheadingBlack,
  display2: display2,
  display3: display3,
  headline1: headline1,
  headline2: headline2,
  headline3: headline3,
  subtitle1: subtitle1,
  body1: body1,
  body2: body2,
  caption1: caption1,
  caption2: caption2,
  tiny1: tiny1
});

const Grid = styled__default.div `
  position: relative;
  ${props => props.marginTop &&
    styled.css `
      margin-top: ${typeof props.marginTop === 'number' ? `${props.marginTop}px` : props.marginTop};
    `}
  ${props => props.marginBottom &&
    styled.css `
      margin-bottom: ${typeof props.marginBottom === 'number' ? `${props.marginBottom}px` : props.marginBottom};
    `}
  margin-left: auto;
  margin-right: auto;
  ${media.sm `
    margin-left: 24px;
    margin-right: 24px;
  `};
  ${media.lg `
    max-width: ${props => (props.maxWidthNone ? 'none' : '960px')};
  `};
`;
var index$4 = ({ ...restProps }) => React.createElement(Grid, Object.assign({}, restProps));

const sizeToPercent = (column) => 100 / (column || 1);
const GridList = styled__default.div ``;
const GridListUl = styled__default.ul `
  overflow: hidden;
  display: block;
  list-style: none;
  margin-block-start: 0;
  margin-block-end: 0;
  padding-inline-start: 0;
  margin-right: -12px;
  margin-left: -12px;
  margin-bottom: -24px;

  ${media.sm `
    margin-right: -4px;
    margin-left: -4px;
    ${props => props.smColumn === 2 &&
    styled.css `
        margin-right: -8px;
        margin-left: -8px;
      `}%;
  `};

  &::before,
  &::after {
    content: '';
    display: table;
  }

  &::after {
    clear: both;
  }
`;
const GridListItem = styled__default.li `
  position: relative;
  min-height: 1px;
  padding-right: 12px;
  padding-left: 12px;
  margin-bottom: 24px;
  float: left;
  box-sizing: border-box;
  width: ${props => sizeToPercent(props.smColumn)}%;

  ${media.sm `
    padding-right: 4px;
    padding-left: 4px;
    ${props => props.smColumn === 2 &&
    styled.css `
        padding-right: 8px;
        padding-left: 8px;
      `}%;
    ${props => styled.css `
        &:nth-child(${props.smColumn}n + 1) {
          clear: left;
        }
      `}
    ${props => props.smColumn === 1 &&
    styled.css `
        .sale-wish-icon {
          > svg {
            width: 32px;
            height: 32px;
          }
        }
      `}
  `}

  ${media.lg `
    ${props => props.lgColumn &&
    styled.css `
        width: ${props => sizeToPercent(props.lgColumn)}%;
      `}
    ${props => props.lgColumn &&
    styled.css `
        &:nth-child(${props.lgColumn}n + 1) {
          clear: left;
        }
      `}
  `}
`;
var index$5 = ({ items, renderItem, smColumn, lgColumn, ...restProps }) => (React.createElement(GridList, Object.assign({}, restProps),
    React.createElement(GridListUl, { smColumn: smColumn }, items.map(item => (React.createElement(GridListItem, { key: item.id, smColumn: smColumn, lgColumn: lgColumn }, renderItem(item)))))));

const SPINNER_TRACK = 'M 50,50 m 0,-44.5 a 44.5,44.5 0 1 1 0,89 a 44.5,44.5 0 1 1 0,-89';
const PATH_LENGTH = 280;
const STROKE_WIDTH = 4;
const strokeWidth = (STROKE_WIDTH * 100) / 50;
const strokeOffset = PATH_LENGTH - PATH_LENGTH * 0.25;
const SpinnerHead = styled__default.path `
  transform-origin: center;
  transition: stroke-dashoffset 2s cubic-bezier(0.4, 1, 0.75, 0.9);
  stroke: ${props => props.backgroundColor || gray600};
  stroke-linecap: round;
`;
const SpinnerTrack = styled__default.path `
  stroke: ${props => props.color || gray200};
`;
const SpinnerContainer = styled__default.div `
  display: flex;
  align-items: center;
  justify-content: center;

  overflow: visible;
  vertical-align: middle;

  svg {
    display: block;
  }

  path {
    fill-opacity: 0;
  }
`;
const SpinnerAnimation = styled__default.span `
  @keyframes pt-spinner-animation {
    from {
      transform: rotate(0deg);
    }
    to {
      transform: rotate(360deg);
    }
  }
  animation: pt-spinner-animation 0.62s ease-in-out infinite;
`;
const Container = styled__default.div `
  display: inline-block;
`;
var Spinner = ({ size = 50, backgroundColor, color, ...restProps }) => (React.createElement(Container, Object.assign({}, restProps),
    React.createElement(SpinnerContainer, null,
        React.createElement(SpinnerAnimation, null,
            React.createElement("svg", { height: size, width: size, viewBox: "0 0 100 100", strokeWidth: strokeWidth },
                React.createElement(SpinnerTrack, { color: color, d: SPINNER_TRACK }),
                React.createElement(SpinnerHead, { backgroundColor: backgroundColor, d: SPINNER_TRACK, pathLength: PATH_LENGTH, strokeDasharray: `${PATH_LENGTH} ${PATH_LENGTH}`, strokeDashoffset: strokeOffset }))))));

const StyledSpinner = styled__default(Spinner) `
  ${props => props.buttonSize === 'lg' &&
    styled.css `
      span,
      span > svg {
        width: 24px;
        height: 24px;
      }
    `};

  ${props => props.buttonSize === 'md' &&
    styled.css `
      span,
      span > svg {
        width: 18px;
        height: 18px;
      }
    `};

  ${props => props.buttonSize === 'sm' &&
    styled.css `
      span,
      span > svg {
        width: 18px;
        height: 18px;
      }
    `};

  ${props => props.buttonSize === 'xs' &&
    styled.css `
      span,
      span > svg {
        width: 16px;
        height: 16px;
      }
    `};
`;
const LeftIcon = styled__default.img.attrs({ alt: '' }) ``;
const RightIcon = styled__default.img.attrs({ alt: '' }) ``;
const buttonStyle = styled.css `
  ${body2WhiteBold};
  color: ${props => props.color || white};
  background-color: ${props => props.backgroundColor || orange600};
  outline: none;
  border: none;
  border-radius: ${props => props.borderRadius || 3}px;
  width: ${props => (props.block ? '100%' : 'auto')};
  display: ${props => (props.block ? 'block' : 'inline-block')};
  text-align: ${props => props.textAlign || 'center'};
  cursor: pointer;
  line-height: 1 !important;
  box-sizing: border-box;
  font-weight: normal;
  vertical-align: middle;

  ${props => props.size === 'lg' &&
    styled.css `
      font-weight: bold;
      font-size: 16px;
      padding: 0 20px;
      height: 48px;

      ${LeftIcon}, ${RightIcon} {
        font-size: 0;
        width: 24px;
        height: 24px;
      }

      ${LeftIcon} {
        margin-right: 4px;
      }

      ${RightIcon} {
        margin-left: 4px;
      }
    `};

  ${props => props.size === 'md' &&
    styled.css `
      font-size: 14px;
      padding: 0 16px;
      height: 40px;

      ${LeftIcon}, ${RightIcon} {
        width: 18px;
        height: 18px;
      }

      ${LeftIcon} {
        margin-right: 4px;
      }

      ${RightIcon} {
        margin-left: 4px;
      }
    `};

  ${props => props.size === 'sm' &&
    styled.css `
      font-size: 14px;
      padding: 0 12px;
      height: 32px;

      ${LeftIcon}, ${RightIcon} {
        width: 18px;
        height: 18px;
      }

      ${LeftIcon} {
        margin-right: 4px;
      }

      ${RightIcon} {
        margin-left: 4px;
      }
    `};

  ${props => props.size === 'xs' &&
    styled.css `
      font-size: 11px;
      padding: 0 10px;
      height: 28px;

      ${LeftIcon}, ${RightIcon} {
        width: 16px;
        height: 16px;
      }

      ${LeftIcon} {
        margin-right: 2px;
      }

      ${RightIcon} {
        margin-left: 2px;
      }
    `};

  * {
    vertical-align: middle;
  }

  &:hover {
    opacity: 0.9;
    text-decoration: none;
  }

  &:disabled {
    cursor: not-allowed;
    opacity: 0.8;
  }
`;
const Button = styled__default.button `
  ${buttonStyle};
`;
const AnchorButtonInner = styled__default.div `
  position: relative;
  top: 50%;
  transform: translateY(-50%);
`;
const anchorButtonStyle = styled.css `
  ${buttonStyle};
  text-decoration: none;
  &:hover {
    color: ${props => props.color || white};
  }
`;
const LinkButton = styled__default(reactRouterDom.Link) `
  ${anchorButtonStyle};
`;
const AnchorButton = styled__default.a `
  ${anchorButtonStyle};
`;
var Button$1 = ({ size = 'md', type = 'button', leftIconSrc, rightIconSrc, children, disabled, loading, to, href, target, ...restProps }) => {
    if (loading) {
        return (React.createElement(Button, Object.assign({ type: type, size: size }, restProps, { disabled: true }),
            React.createElement(StyledSpinner, { buttonSize: size })));
    }
    const options = {};
    if (target === '_blank') {
        options.rel = 'noopener noreferrer';
    }
    const innerElements = (React.createElement(React.Fragment, null,
        Boolean(leftIconSrc) && React.createElement(LeftIcon, { src: leftIconSrc }),
        React.createElement("span", null, children),
        Boolean(rightIconSrc) && React.createElement(RightIcon, { src: rightIconSrc })));
    const anchorButtonElements = React.createElement(AnchorButtonInner, null, innerElements);
    if (to) {
        return (React.createElement(LinkButton, Object.assign({ to: to, target: target, size: size, disabled: disabled }, options, restProps), anchorButtonElements));
    }
    if (href) {
        return (React.createElement(AnchorButton, Object.assign({ href: href, target: target, size: size, disabled: disabled }, options, restProps), anchorButtonElements));
    }
    return (React.createElement(Button, Object.assign({ type: type, size: size, disabled: disabled }, restProps), innerElements));
};

const Footer = styled__default.div `
  margin-top: 24px;
`;
var Footer$1 = ({ buttonTitle, color = gray600, backgroundColor = white, style = {
    border: `1px solid ${gray200}`,
    fontWeight: 'bold',
}, ...restProps }) => (React.createElement(Footer, null,
    React.createElement(Button$1, Object.assign({ color: color, backgroundColor: backgroundColor, style: style }, restProps, { block: true }), buttonTitle)));

// @flow
const customStyle = styled.css `
  color: ${props => props.color || gray800};
  margin-top: ${props => props.marginTop || 0}px;
  margin-bottom: ${props => props.marginBottom || 0}px;
  margin-left: ${props => props.marginLeft || 0}px;
  margin-right: ${props => props.marginRight || 0}px;
  ${props => props.textAlign && `text-align: ${props.textAlign}`};
`;
const Headline1 = styled__default.h1 `
  ${headline1};
  ${props => props.display &&
    [2, '2'].includes(props.display) &&
    styled.css `
      ${display2};
    `};
  ${props => props.display &&
    [3, '3'].includes(props.display) &&
    styled.css `
      ${display3};
    `};
  ${customStyle};
`;
const Headline2 = styled__default.h2 `
  ${headline2};
  color: ${props => props.color || gray800};
  ${props => props.display &&
    [2, '2'].includes(props.display) &&
    styled.css `
      ${display2};
    `};
  ${props => props.display &&
    [3, '3'].includes(props.display) &&
    styled.css `
      ${display3};
    `};
  ${customStyle};
`;
const Headline3 = styled__default.h3 `
  ${headline3};
  color: ${props => props.color || gray800};
  ${props => props.display &&
    [2, '2'].includes(props.display) &&
    styled.css `
      ${display2};
    `};
  ${props => props.display &&
    [3, '3'].includes(props.display) &&
    styled.css `
      ${display3};
    `};
  ${customStyle};
`;
const Subtitle1 = styled__default.h4 `
  ${subtitle1};
  ${customStyle};
`;
const Body1 = styled__default.div `
  ${body1};
  line-height: 24px;
  ${customStyle};
`;
const Body1Paragraph = styled__default.p `
  ${body1};
  line-height: 28px;
  ${customStyle};
`;
const Body2 = styled__default.div `
  ${body2};
  line-height: 20px;
  ${customStyle};
`;
const Body2Paragraph = styled__default.div `
  ${body2};
  line-height: 24px;
  ${customStyle};
`;
const Caption1 = styled__default.div `
  ${caption1};
  ${customStyle};
`;
const Caption2 = styled__default.div `
  ${caption2};
  ${customStyle};
`;
const Tiny1 = styled__default.div `
  ${tiny1};
  ${customStyle};
`;
const getCurrentSize = (currentWidth) => {
    let windowSize = 'md';
    if (!currentWidth) {
        return windowSize;
    }
    Object.keys(SIZES).forEach(key => {
        const size = SIZES[key];
        const conditions = Object.keys(size).map(sizeOption => {
            const BreakPoint = size[sizeOption];
            if (BreakPoint && sizeOption === 'minWidth') {
                return currentWidth >= BreakPoint;
            }
            if (BreakPoint && sizeOption === 'maxWidth') {
                return currentWidth <= BreakPoint;
            }
            return 'SKIP';
        });
        if (!conditions.includes(false) && conditions.join() !== 'SKIP,SKIP') {
            windowSize = key;
        }
        return windowSize;
    });
    return windowSize;
};
const capitalize = (str) => (str ? str[0].toUpperCase() + str.slice(1) : null);
const throttle = (callback, limit) => {
    let wait = false;
    return () => {
        if (!wait) {
            callback.call();
            wait = true;
            setTimeout(() => {
                wait = false;
            }, limit);
        }
    };
};
const TypographyList = {
    Headline1,
    Headline2,
    Headline3,
    Subtitle1,
    Body1,
    Body1Paragraph,
    Body2,
    Body2Paragraph,
    Caption1,
    Caption2,
    Tiny1,
};
class Typography extends React.PureComponent {
    constructor() {
        super(...arguments);
        this.state = {
            width: 0,
        };
        this.updateWindowDimensions = throttle(() => {
            this.setState({ width: window.innerWidth });
        }, 60);
    }
    componentDidMount() {
        const { lg, md, sm } = this.props;
        if ([lg, md, sm].filter(Boolean).length >= 2) {
            this.updateWindowDimensions();
            window.addEventListener('resize', this.updateWindowDimensions);
        }
    }
    componentWillUnmount() {
        const { lg, md, sm } = this.props;
        if ([lg, md, sm].filter(Boolean).length >= 2) {
            window.removeEventListener('resize', this.updateWindowDimensions);
        }
    }
    render() {
        const { width } = this.state;
        const { children, ...restProps } = this.props;
        const lg = capitalize(this.props.lg);
        const md = capitalize(this.props.md);
        const sm = capitalize(this.props.sm);
        let Element = null;
        if (!lg && md && !sm) {
            Element = TypographyList[md];
            return React.createElement(Element, Object.assign({}, restProps), children);
        }
        const currentSize = getCurrentSize(width);
        if (lg && currentSize === 'lg') {
            Element = TypographyList[lg || md];
        }
        else if (md && currentSize === 'md') {
            Element = TypographyList[md];
        }
        else if (sm && currentSize === 'sm') {
            Element = TypographyList[sm || md];
        }
        else {
            Element = TypographyList[md || 'Body1'];
        }
        return React.createElement(Element, Object.assign({}, restProps), children);
    }
}

const Header = styled__default.div `
  margin-bottom: 16px;
  a {
    display: inline-block;
    position: relative;
    padding-right: 24px;
  }
`;
const HeaderTitle = styled__default(Typography) `
  display: inline-block;
`;
const SubTitle = styled__default.p `
  ${body2Paragraph}
  margin-top: 4px;
`;
const HeaderIcon = styled__default.span `
  position: absolute;
  top: 50%;
  transform: translateY(-50%);
  svg {
    display: block;
  }
`;
var Header$1 = ({ title, subTitle, typography, to, href, target, ...restProps }) => {
    const options = {};
    if (target === '_blank') {
        options.rel = 'noopener noreferrer';
    }
    const sectionHeaderTitle = (React.createElement(HeaderTitle, Object.assign({ md: typography || 'Subtitle1' }, restProps), title));
    const sectionHeaderIcon = (React.createElement(HeaderIcon, null,
        React.createElement("svg", { width: 24, height: 24, viewBox: "0 0 24px 24px" },
            React.createElement("path", { fill: gray300, fillRule: "evenodd", d: "M8.5 18.5l6-6.5-6-6.5L10 4l7.5 8-7.5 8z" }))));
    if (to) {
        return (React.createElement(Header, null,
            React.createElement(reactRouterDom.Link, Object.assign({ to: to, target: target }, options),
                sectionHeaderTitle,
                sectionHeaderIcon),
            subTitle && React.createElement(SubTitle, null, subTitle)));
    }
    if (href) {
        return (React.createElement(Header, null,
            React.createElement("a", Object.assign({ href: href, target: target }, options),
                sectionHeaderTitle,
                sectionHeaderIcon),
            subTitle && React.createElement(SubTitle, null, subTitle)));
    }
    return (React.createElement(Header, null,
        sectionHeaderTitle,
        subTitle && React.createElement(SubTitle, null, subTitle)));
};

const Section = styled__default.section ``;
var index$6 = ({ title, titleStyle, subTitle, buttonTitle, buttonStyle, to, href, target, onClick, children, ...restProps }) => (React.createElement(Section, Object.assign({}, restProps),
    title && !buttonTitle ? (React.createElement(Header$1, Object.assign({ title: title, to: to, href: href, target: target, onClick: onClick, subTitle: subTitle }, titleStyle))) : (React.createElement(Header$1, Object.assign({ title: title, subTitle: subTitle }, titleStyle))),
    children,
    buttonTitle && (React.createElement(Footer$1, Object.assign({ buttonTitle: buttonTitle, to: to, href: href, target: target, onClick: onClick }, buttonStyle)))));

const sizeToPercent$1 = (size) => ((size || 12) / 12) * 100;
const Col = styled__default.div `
  position: relative;
  min-height: 1px;
  padding-right: 12px;
  padding-left: 12px;
  float: left;
  box-sizing: border-box;
  ${media.sm `
    width: ${props => sizeToPercent$1(props.sm)}%;
    padding-right: 4px;
    padding-left: 4px;
    ${props => props.smOffset &&
    styled.css `
        margin-left: ${sizeToPercent$1(props.smOffset)}%;
      `}
  `}

  ${media.md `
    width: ${props => sizeToPercent$1(props.md || props.sm)}%;
    ${props => (props.mdOffset || props.smOffset) &&
    styled.css `
        margin-left: ${sizeToPercent$1(props.mdOffset || props.smOffset)}%;
      `}
  `}

  ${media.lg `
    width: ${props => sizeToPercent$1(props.lg || props.md || props.sm)}%;
    ${props => (props.lgOffset || props.mdOffset || props.smOffset) &&
    styled.css `
        margin-left: ${sizeToPercent$1(props.lgOffset || props.mdOffset || props.smOffset)}%;
      `}
  `};
`;

const Row = styled__default.div `
  zoom: 1;
  ${props => props.marginTop &&
    styled.css `
      margin-top: ${typeof props.marginTop === 'number' ? `${props.marginTop}px` : props.marginTop};
    `}
  ${props => props.marginBottom &&
    styled.css `
      margin-bottom: ${typeof props.marginBottom === 'number' ? `${props.marginBottom}px` : props.marginBottom};
    `}
  margin-right: -12px;
  margin-left: -12px;
  ${media.sm `
    margin-right: -4px;
    margin-left: -4px;
  `};

  &::before,
  &::after {
    content: '';
    display: table;
  }

  &::after {
    clear: both;
  }
`;
var index$7 = ({ ...restProps }) => React.createElement(Row, Object.assign({}, restProps));

const Card = styled__default.div `
  position: relative;
  width: 100%;
`;
const CoverImage = styled__default.div `
  overflow: hidden;
  border-radius: 2px;
  ${props => {
    const ratios = props.coverImageRatio.split('*');
    return styled.css `
      position: relative;
      padding-bottom: ${(Number(ratios[1]) / Number(ratios[0])) * 100}%;
      img {
        position: absolute;
        top: 0;
        left: 0;
        width: 100%;
        height: 100%;
        object-fit: cover;
      }
    `;
}}
`;
const Body = styled__default.div `
  margin-top: 4px;
  > div {
    margin-top: 2px;
  }
`;
const Title = styled__default.div `
  ${body2Black};
  overflow: hidden;
  display: -webkit-box;
  -webkit-line-clamp: 3;
  -webkit-box-orient: vertical;
`;
const anchorCardStyle = styled.css `
  img {
    transition: transform 0.5s, opacity 0.5s;
    opacity: 1;
    transform: scale(1);
  }
  &:hover,
  &:focus {
    img {
      opacity: 0.9;
      transform: scale(1.1);
    }
  }
`;
const LinkCardInner = styled__default(reactRouterDom.Link) `
  ${anchorCardStyle};
`;
const AnchorCardInner = styled__default.a `
  ${anchorCardStyle};
`;
var Card$1 = ({ title, coverImage, coverImageSrcSet, coverImageAlt, coverImageRatio = '4*3', extraTop, extraBottom, children, to, href, target, ...restProps }) => {
    const options = {};
    if (target === '_blank') {
        options.rel = 'noopener noreferrer';
    }
    const imgElements = () => {
        if (typeof coverImage === 'string') {
            return coverImageSrcSet ? (React.createElement("img", { src: coverImage, alt: coverImageAlt || '', srcSet: coverImageSrcSet })) : (React.createElement("img", { src: coverImage, alt: coverImageAlt || '' }));
        }
        return coverImage;
    };
    const innerElements = (React.createElement(React.Fragment, null,
        React.createElement(CoverImage, { coverImageRatio: coverImageRatio }, imgElements()),
        React.createElement(Body, null,
            extraTop,
            React.createElement(Title, null, title),
            extraBottom)));
    if (to) {
        return (React.createElement(Card, null,
            React.createElement(LinkCardInner, Object.assign({ to: to, target: target }, options), innerElements),
            children));
    }
    if (href) {
        return (React.createElement(Card, null,
            React.createElement(AnchorCardInner, Object.assign({ href: href, target: target }, options), innerElements),
            children));
    }
    return (React.createElement(Card, Object.assign({}, restProps),
        innerElements,
        children));
};

const KlassCard = styled__default(Card$1) ``;
const CreatorName = styled__default.div `
  ${tiny1BlackBold}
`;
const SubInfo = styled__default.div `
  ${tiny1Gray};
`;
const OpenState = styled__default.span `
  display: inline-block;
`;
const Dot = styled__default.span `
  display: inline-block;
  width: 11px;
  text-align: center;
`;
const Sale = styled__default.span `
  ${tiny1BlackBold}
  display: inline-block;
  color: ${orange600};
`;
const WishlistButton = styled__default.button `
  position: absolute;
  top: 8px;
  right: 8px;
  width: 32px;
  height: 32px;
  padding: 0;
  border: none;
  background: transparent;
  cursor: pointer;
  &:focus {
    outline: none;
  }
`;
const ReservationButton = styled__default(Button$1).attrs({ size: 'sm' }) `
  ${tiny1Gray};
  width: 100%;
  margin-top: 8px;
  color: ${props => (props.reservationed ? 'white' : red600)};
  background-color: ${props => (props.reservationed ? red600 : red000)};
`;
const ReservationIcon = styled__default.span `
  display: inline-block;
  vertical-align: middle;
  margin-right: 2px;
`;
const LINE_HEART_D = 'M17.586 15.086c2.07-2.07 2.914-3.572 2.914-5.586A3.5 3.5 0 0 0 17 6c-1.074 0-1.92.392-2.829 1.19a14.88 14.88 0 0 0-.757.724L12 9.328l-1.414-1.414a14.88 14.88 0 0 0-.757-.724C8.919 6.392 8.074 6 7 6a3.5 3.5 0 0 0-3.5 3.5c0 2.014.844 3.516 2.914 5.586 1.038 1.037 2.91 2.277 5.586 3.67 2.677-1.393 4.548-2.633 5.586-3.67zM5 16.5c-1.911-1.911-3.5-3.962-3.5-7A5.5 5.5 0 0 1 7 4c2.5 0 4 1.5 5 2.5 1-1 2.5-2.5 5-2.5a5.5 5.5 0 0 1 5.5 5.5c0 3.038-1.589 5.089-3.5 7-1.333 1.333-3.667 2.833-7 4.5-3.333-1.667-5.667-3.167-7-4.5z';
const FILL_HEART_D = 'M5 16.5c-1.911-1.911-3.5-3.962-3.5-7A5.5 5.5 0 0 1 7 4c2.5 0 4 1.5 5 2.5 1-1 2.5-2.5 5-2.5a5.5 5.5 0 0 1 5.5 5.5c0 3.038-1.589 5.089-3.5 7-1.333 1.333-3.667 2.833-7 4.5-3.333-1.667-5.667-3.167-7-4.5z';
var index$8 = ({ creatorName, state = 'sale', openDate, sale, loading, reservationed, reservationCount = 0, onReservationClick, wishlisted, onWishlistClick, coverImageRatio = '16*9', ...restProps }) => {
    const creatorNameElement = React.createElement(CreatorName, null,
        "by ",
        creatorName);
    if (state === 'sale' || state === 'funding') {
        const subInforElement = (React.createElement(SubInfo, null,
            React.createElement(OpenState, null, state === 'sale' ? '바로 수강 가능' : `${openDate} 오픈`),
            sale && (React.createElement(React.Fragment, null,
                React.createElement(Dot, null, "\u30FB"),
                React.createElement(Sale, null,
                    sale,
                    "% \uD560\uC778")))));
        return (React.createElement(KlassCard, Object.assign({ extraTop: creatorNameElement, extraBottom: subInforElement, coverImageRatio: coverImageRatio }, restProps),
            React.createElement(WishlistButton, { onClick: onWishlistClick, className: "sale-wish-icon" },
                React.createElement("svg", { width: 24, height: 24, viewBox: "0 0 24 24" },
                    React.createElement("path", { fill: wishlisted ? red600 : 'white', fillRule: "evenodd", d: wishlisted ? FILL_HEART_D : LINE_HEART_D })))));
    }
    if (state === 'preview') {
        return (React.createElement(KlassCard, Object.assign({ extraTop: creatorNameElement, coverImageRatio: coverImageRatio }, restProps),
            React.createElement(ReservationButton, { reservationed: reservationed, loading: loading, onClick: onReservationClick },
                React.createElement(ReservationIcon, null,
                    React.createElement("svg", { width: 16, height: 16, viewBox: "0 0 24 24" },
                        React.createElement("path", { fill: reservationed ? 'white' : red600, fillRule: "evenodd", d: reservationed ? FILL_HEART_D : LINE_HEART_D }))),
                reservationCount,
                "\uBA85")));
    }
    return React.createElement(KlassCard, Object.assign({ coverImageRatio: coverImageRatio }, restProps));
};

// @flow
const Bar = styled__default.div `
  border-radius: 2px;
  background-color: ${props => props.barColor || orange600};
  width: ${props => props.value || 0}%;
  transition: width 0.3s ease-in-out;
`;
const Container$1 = styled__default.div `
  border-radius: 2px;
  background-color: ${props => props.backgroundColor || gray200};
  flex-grow: 1;

  ${props => props.height &&
    styled.css `
      height: ${props.height}px;

      ${Bar} {
        height: ${props.height}px;
      }
    `};
`;
var index$9 = ({ value = 0, height = 4, backgroundColor, barColor, ...restProps }) => (React.createElement(Container$1, Object.assign({ backgroundColor: backgroundColor, height: height }, restProps),
    React.createElement(Bar, { barColor: barColor, value: Number(value) > 100 ? 100 : value })));

// @flow
const Container$2 = styled__default.div `
  display: flex;
  align-items: center;
  justify-content: space-between;
  border-radius: 16px;
  background-color: ${props => props.backgroundColor || gray700};
  height: 32px;
`;
const Content = styled__default.div `
  ${body2Gray};
  display: flex;
  align-items: center;
  page-break-after: always;
  break-after: always;
  border-radius: 16px;
  flex: 1;
  justify-content: center;
  height: 100%;
  color: ${props => props.color || gray500};
  ${props => props.active &&
    styled.css `
      background-color: ${props => props.activeBackgroundColor || orange600};
      color: ${props => props.activeColor || white};
      font-weight: bold;
    `};
`;
const Chevron = styled__default.img.attrs({
    src: 'https://s3.ap-northeast-2.amazonaws.com/class101-ui/images/ic-chevron-gray.png',
    alt: '>',
}) `
  width: 24px;
  height: 24px;
  margin: 0 12px;
`;
var index$a = ({ value, items, color, backgroundColor, activeBackgroundColor, activeColor, ...restProps }) => (React.createElement(Container$2, Object.assign({ backgroundColor: backgroundColor }, restProps), items &&
    items
        .map((item, index) => (React.createElement(Content, { key: String(index), active: Boolean(value && String(value) === String(item.value)), color: color, activeBackgroundColor: activeBackgroundColor, activeColor: activeColor }, item.label || item.value)))
        .reduce((prev, curr) => (React.createElement(React.Fragment, null,
        prev,
        React.createElement(Chevron, null),
        curr)))));

// @flow
const StyledInput = styled__default.input `
  ${body2Black}
  border-radius: 1px;
  background-color: white;
  border: solid 1px ${gray300};
  width: 100%;
  height: 48px;
  padding: 0 16px;
  &:hover {
    border: solid 1px ${gray400};
  }
  &:disabled {
    background-color: ${gray50};
    &:hover {
      cursor: not-allowed;
    }
  }
  &:focus {
    outline: none;
    border-color: ${gray800};
  }
  &::-webkit-input-placeholder {
    color: ${gray500};
  }
  &::-moz-placeholder {
    color: ${gray500};
  }
  &:-ms-input-placeholder {
    color: ${gray500};
  }
  &:-moz-placeholder {
    color: ${gray500};
  }

  &.error {
    border: solid 1px ${redError};
  }

  &.warn {
    border: solid 1px ${orange500};
  }
`;
const DescriptionStyle = styled.css `
  margin: 0;
  margin-top: 4px;
  font-size: 11px;
  line-height: 16px;
  font-weight: normal;

  * {
    vertical-align: middle;
  }
`;
const ErrorText = styled__default.h6 `
  ${DescriptionStyle};
  color: ${redError};
`;
const WarnText = styled__default.h6 `
  ${DescriptionStyle};
  color: ${orange500};
`;
const AllowText = styled__default.h6 `
  ${DescriptionStyle};
  color: ${gray600};
`;
const Container$3 = styled__default.div `
  display: ${props => (props.inline ? 'inline-block' : 'block')};
`;
const DescriptionIcon = styled__default.img.attrs({ alt: '!' }) `
  width: 16px;
  height: 16px;
  margin-right: 2px;
`;
class Input extends React.PureComponent {
    render() {
        const { type, className, style, inputStyle, inline, allowMessage, warnMessage, errorMessage, size, ...restProps } = this.props;
        return (React.createElement(Container$3, { style: style, inline: inline },
            React.createElement(StyledInput, Object.assign({ className: `${className || ''} ${errorMessage ? ' error' : ''} ${warnMessage ? ' warn' : ''}`, type: type, style: inputStyle }, restProps)),
            allowMessage && !errorMessage && React.createElement(AllowText, null, allowMessage),
            errorMessage && (React.createElement(ErrorText, null,
                React.createElement(DescriptionIcon, { src: "https://s3.ap-northeast-2.amazonaws.com/class101-ui/images/ic-danger-red.png" }),
                React.createElement("span", null, errorMessage))),
            warnMessage && (React.createElement(WarnText, null,
                React.createElement(DescriptionIcon, { src: "https://s3.ap-northeast-2.amazonaws.com/class101-ui/images/ic-danger-yellow.png" }),
                React.createElement("span", null, warnMessage)))));
    }
}
Input.defaultProps = {
    size: 'md',
    type: 'text',
};

// @flow
const StyledTextarea = styled__default.textarea `
  ${body2Black}
  border-radius: 1px;
  background-color: white;
  border: solid 1px ${gray300};
  width: 100%;
  height: 104px;
  padding: 12px 16px;
  box-sizing: border-box;

  &:hover {
    border: solid 1px ${gray400};
  }
  &:disabled {
    background-color: ${gray000};
    &:hover {
      cursor: not-allowed;
    }
  }
  &:focus {
    outline: none;
    border-color: ${gray800};
  }
  &::-webkit-input-placeholder {
    color: ${gray500};
  }
  &::-moz-placeholder {
    color: ${gray500};
  }
  &:-ms-input-placeholder {
    color: ${gray500};
  }
  &:-moz-placeholder {
    color: ${gray500};
  }

  &.error {
    border: solid 1px ${redError};
  }

  &.warn {
    border: solid 1px ${orange500};
  }
`;
const DescriptionStyle$1 = styled.css `
  margin: 0;
  margin-top: 4px;
  font-size: 11px;
  line-height: 16px;
  font-weight: normal;

  * {
    vertical-align: middle;
  }
`;
const ErrorText$1 = styled__default.h6 `
  ${DescriptionStyle$1};
  color: ${redError};
`;
const WarnText$1 = styled__default.h6 `
  ${DescriptionStyle$1};
  color: ${orange500};
`;
const AllowText$1 = styled__default.h6 `
  ${DescriptionStyle$1};
  color: ${gray600};
`;
const Container$4 = styled__default.div `
  display: ${props => (props.inline ? 'inline-block' : 'block')};
`;
const DescriptionIcon$1 = styled__default.img.attrs({ alt: '!' }) `
  width: 16px;
  height: 16px;
  margin-right: 2px;
`;
class Textarea extends React.PureComponent {
    render() {
        const { className, style, inputStyle, inline, allowMessage, warnMessage, errorMessage, ...restProps } = this.props;
        return (React.createElement(Container$4, { style: style, inline: inline },
            React.createElement(StyledTextarea, Object.assign({ className: `${className || ''} ${errorMessage ? ' error' : ''} ${warnMessage ? ' warn' : ''}`, style: inputStyle }, restProps)),
            allowMessage && !errorMessage && React.createElement(AllowText$1, null, allowMessage),
            errorMessage && (React.createElement(ErrorText$1, null,
                React.createElement(DescriptionIcon$1, { src: "https://s3.ap-northeast-2.amazonaws.com/class101-ui/images/ic-danger-red.png" }),
                React.createElement("span", null, errorMessage))),
            warnMessage && (React.createElement(WarnText$1, null,
                React.createElement(DescriptionIcon$1, { src: "https://s3.ap-northeast-2.amazonaws.com/class101-ui/images/ic-danger-yellow.png" }),
                React.createElement("span", null, warnMessage)))));
    }
}

const Container$5 = styled__default.div `
  display: inline-block;
`;
const BadgeCounter = styled__default.label `
  ${tiny1WhiteBold};
  line-height: 1;
  min-width: 20px;
  height: 20px;
  display: table-cell;
  text-align: center;
  vertical-align: middle;
  border-radius: 10px;
  background-color: ${props => props.backgroundColor || red600};
  color: ${props => props.color || white};
  padding: 0 6px;
`;
var Badge = ({ children, color, backgroundColor, ...restProps }) => (React.createElement(Container$5, Object.assign({}, restProps),
    React.createElement(BadgeCounter, { color: color, backgroundColor: backgroundColor }, children)));

const BORDER_SIZE = 1;
const Title$1 = styled__default.span `
  ${body1BlackBold};
  transition: font-size 0.4s ease-in-out;
`;
const InnerHeader = styled__default.div `
  padding: 10px 24px;
  cursor: pointer;
  transition: padding 0.4s ease-in-out;

  div,
  span {
    vertical-align: middle;
  }
`;
const Chevron$1 = styled__default.img.attrs({
    src: 'https://s3.ap-northeast-2.amazonaws.com/class101-ui/images/ic-chevron-gray.png',
    alt: '>',
}) `
  width: 24px;
  height: 24px;
  position: absolute;
  right: 24px;
  transition: transform 0.4s ease-in-out, top 0.4s ease-in-out;
  transform: rotate(${props => props.rotate || 270}deg);
`;
const Container$6 = styled__default.div `
  z-index: ${props => (props.isOpened ? props.openedZIndex : props.zIndex) || 2001};
  position: ${props => (props.fullScreen ? 'fixed' : 'relative')};
  width: ${props => (props.fullScreen ? '100vw' : '100%')};
  height: ${props => (props.fullScreen ? '90vh' : '100%')};
  bottom: calc(48px - 100%);
  left: 0;
  overflow: ${props => (props.fullScreen ? 'visible' : 'hidden')};
  transition: transform 0.4s ease-in-out;
  border-top-left-radius: 12px;
  border-top-right-radius: 12px;
  background-color: ${white};
  box-shadow: 0 -1px 3px -1px rgba(41, 42, 43, 0.16), 0 0 1px 1px rgba(0, 0, 0, 0.04);
  box-sizing: border-box;
  zoom: 1;
  ${props => props.isOpened
    ? styled.css `
          transform: translateY(calc(48px - 100% + ${BORDER_SIZE}px));

          ${Title$1} {
            ${subheadingBlackBold};
          }

          ${InnerHeader} {
            padding-top: 24px;
          }

          ${Chevron$1} {
            top: ${24 - BORDER_SIZE}px;
          }
        `
    : styled.css `
          transform: translateY(${props => (props.fullScreen ? `calc(-10% - ${BORDER_SIZE + 1}px)` : 0)});

          ${Chevron$1} {
            top: ${12 - BORDER_SIZE}px;
          }
        `}
`;
const Header$2 = styled__default.div `
  position: absolute;
  top: 0;
  left: 0;
  width: 100%;
  border-top-left-radius: 12px;
  border-top-right-radius: 12px;
  background-color: ${white};
`;
const BadgeCounter$1 = styled__default(Badge) `
  margin-left: 4px;
`;
const Content$1 = styled__default.div `
  transition: margin 0.4s ease-in-out;
  margin-top: ${props => props.marginTop || 0}px;
  width: 100%;
  height: calc(${props => (props.fullScreen ? 90 : 100)}% - ${props => props.marginTop || 0}px - ${BORDER_SIZE + 3}px);
  overflow: auto;
  padding: 0 24px;
`;
const FixedContent = styled__default.div `
  padding: 0 24px 10px;
`;
const BackgroundWindow = styled__default.div `
  position: fixed;
  top: 0;
  left: 0;
  width: 100vw;
  height: 100vh;
  background-color: rgba(0, 0, 0, 0.7);
  overflow: visible;
  z-index: ${props => (props.zIndex ? props.zIndex - 1 : 2000)};
`;
class BottomSheet extends React.PureComponent {
    constructor() {
        super(...arguments);
        this.state = {
            isOpened: false,
        };
        this.headerElement = null;
        this.onChangeToggle = () => {
            const { isOpened } = this.state;
            this.setState({ isOpened: !isOpened });
        };
        this.preventDefault = (e) => {
            e.preventDefault();
        };
    }
    render() {
        const { title, renderFixedContent, badgeCount, renderContent, fullScreen = true, zIndex, openedZIndex, ...restProps } = this.props;
        const isOpened = this.props.isOpened || this.state.isOpened;
        const element = (React.createElement(Container$6, Object.assign({ isOpened: isOpened, fullScreen: fullScreen, zIndex: zIndex, openedZIndex: openedZIndex }, restProps),
            this.headerElement && this.headerElement.clientHeight && renderContent && (React.createElement(Content$1, { fullScreen: fullScreen, marginTop: this.headerElement.clientHeight + 17 }, renderContent())),
            React.createElement(Header$2, { ref: ref => {
                    if (!this.headerElement)
                        this.headerElement = ref;
                } },
                React.createElement(InnerHeader, { onMouseDown: this.onChangeToggle, onTouchStart: this.onChangeToggle, onTouchEnd: this.preventDefault },
                    React.createElement(Title$1, null, title || ''),
                    badgeCount && React.createElement(BadgeCounter$1, null, badgeCount),
                    React.createElement(Chevron$1, { rotate: isOpened ? 90 : 270 })),
                renderFixedContent && React.createElement(FixedContent, null, renderFixedContent()))));
        if (fullScreen) {
            return (React.createElement("div", null,
                isOpened && (React.createElement(BackgroundWindow, { zIndex: openedZIndex || zIndex, onMouseDown: this.onChangeToggle, onTouchStart: this.onChangeToggle, onTouchEnd: this.preventDefault })),
                element));
        }
        return element;
    }
}

const Label = styled__default.label `
  ${body2Black};
  margin: 0 0 8px;
  color: ${props => props.labelColor || gray800};
`;
const Container$7 = styled__default.div `
  display: flex;
  flex-direction: column;
  margin: 0 0 16px;

  ${props => props.inline &&
    styled.css `
      flex-direction: row;
      align-items: center;

      & * {
        margin-right: 4px;

        &:last-child {
          margin-right: 0;
        }
      }

      ${Label} {
        margin-bottom: 0;
      }
    `};
`;
class FormGroup extends React.PureComponent {
    render() {
        const { label, labelColor, inline, children, ...restProps } = this.props;
        return (React.createElement(Container$7, Object.assign({ inline: inline }, restProps),
            React.createElement(Label, { labelColor: labelColor }, label || ''),
            children));
    }
}

const Container$8 = styled__default.div `
  display: flex;
  align-items: stretch;

  ${props => props.vertical
    ? styled.css `
          flex-direction: column;

          & * {
            box-sizing: border-box;
            border-radius: 0;

            &:first-child {
              border-top-left-radius: 1px;
              border-top-right-radius: 1px;
            }

            &:last-child {
              border-bottom-left-radius: 1px;
              border-bottom-right-radius: 1px;
            }
          }
        `
    : styled.css `
          flex-direction: row;

          & * {
            box-sizing: border-box;
            border-radius: 0;

            &:first-child {
              border-top-left-radius: 1px;
              border-bottom-left-radius: 1px;
            }

            &:last-child {
              border-top-right-radius: 1px;
              border-bottom-right-radius: 1px;
            }
          }
        `}

  ${props => props.block &&
    styled.css `
      & * {
        flex: 1 1 auto;
      }
    `};
`;
class ControlGroup extends React.PureComponent {
    render() {
        const { block, children, vertical, ...restProps } = this.props;
        return (React.createElement(Container$8, Object.assign({ block: block, vertical: vertical }, restProps), children));
    }
}

var Headline1$1 = ({ children, ...restProps }) => (React.createElement(Typography, Object.assign({ md: "Headline1" }, restProps), children));

var Headline2$1 = ({ children, ...restProps }) => (React.createElement(Typography, Object.assign({ md: "Headline2" }, restProps), children));

var Headline3$1 = ({ children, ...restProps }) => (React.createElement(Typography, Object.assign({ md: "Headline3" }, restProps), children));

var Subtitle1$1 = ({ children, ...restProps }) => (React.createElement(Typography, Object.assign({ md: "Subtitle1" }, restProps), children));

var Body1$1 = ({ paragraph, children, ...restProps }) => (React.createElement(Typography, Object.assign({ md: `Body1${paragraph ? 'Paragraph' : ''}` }, restProps), children));

var Body2$1 = ({ paragraph, children, ...restProps }) => (React.createElement(Typography, Object.assign({ md: `Body2${paragraph ? 'Paragraph' : ''}` }, restProps), children));

var Caption1$1 = ({ children, ...restProps }) => (React.createElement(Typography, Object.assign({ md: "Caption1" }, restProps), children));

var Caption2$1 = ({ children, ...restProps }) => (React.createElement(Typography, Object.assign({ md: "Caption2" }, restProps), children));

var Tiny1$1 = ({ children, ...restProps }) => (React.createElement(Typography, Object.assign({ md: "Tiny1" }, restProps), children));

var index$b = styled.createGlobalStyle `
  @font-face {
    font-family: 'SpoqaHanSans';
    font-weight: 700;
    src: local('Spoqa Han Sans Bold'),
    url('https://cdn.rawgit.com/spoqa/spoqa-han-sans/01ff0283/Subset/SpoqaHanSans/SpoqaHanSansBold.woff2') format('woff2'),
    url('https://cdn.rawgit.com/spoqa/spoqa-han-sans/01ff0283/Subset/SpoqaHanSans/SpoqaHanSansBold.woff') format('woff'),
    url('https://cdn.rawgit.com/spoqa/spoqa-han-sans/01ff0283/Subset/SpoqaHanSans/SpoqaHanSansBold.ttf') format('truetype');
  }

  @font-face {
    font-family: 'SpoqaHanSans';
    font-weight: 400;
    src: local('Spoqa Han Sans Regular'),
    url('https://cdn.rawgit.com/spoqa/spoqa-han-sans/01ff0283/Subset/SpoqaHanSans/SpoqaHanSansRegular.woff2') format('woff2'),
    url('https://cdn.rawgit.com/spoqa/spoqa-han-sans/01ff0283/Subset/SpoqaHanSans/SpoqaHanSansRegular.woff') format('woff'),
    url('https://cdn.rawgit.com/spoqa/spoqa-han-sans/01ff0283/Subset/SpoqaHanSans/SpoqaHanSansRegular.ttf') format('truetype');
  }

  @font-face {
    font-family: 'SpoqaHanSans';
    font-weight: 300;
    src: local('Spoqa Han Sans Light'),
    url('https://cdn.rawgit.com/spoqa/spoqa-han-sans/01ff0283/Subset/SpoqaHanSans/SpoqaHanSansLight.woff2') format('woff2'),
    url('https://cdn.rawgit.com/spoqa/spoqa-han-sans/01ff0283/Subset/SpoqaHanSans/SpoqaHanSansLight.woff') format('woff'),
    url('https://cdn.rawgit.com/spoqa/spoqa-han-sans/01ff0283/Subset/SpoqaHanSans/SpoqaHanSansLight.ttf') format('truetype');
  }

  @import url(https://cdn.rawgit.com/moonspam/NanumSquare/master/nanumsquare.css);

  body {
    font-family: 'SpoqaHanSans', 'Sans-serif';
  }
  a {
    text-decoration: none;
    color: inherit;
  }
  p, ul {
    padding: 0, margin: 0
  }
`;

exports.Colors = index$1;
exports.BreakPoints = index;
exports.TextStyles = index$3;
exports.Icon = index$2;
exports.Grid = index$4;
exports.GridList = index$5;
exports.Section = index$6;
exports.Col = Col;
exports.Row = index$7;
exports.Card = Card$1;
exports.KlassCard = index$8;
exports.Spinner = Spinner;
exports.ProgressBar = index$9;
exports.ProgressState = index$a;
exports.Button = Button$1;
exports.Input = Input;
exports.Textarea = Textarea;
exports.BottomSheet = BottomSheet;
exports.Badge = Badge;
exports.FormGroup = FormGroup;
exports.ControlGroup = ControlGroup;
exports.Headline1 = Headline1$1;
exports.Headline2 = Headline2$1;
exports.Headline3 = Headline3$1;
exports.Subtitle1 = Subtitle1$1;
exports.Body1 = Body1$1;
exports.Body2 = Body2$1;
exports.Caption1 = Caption1$1;
exports.Caption2 = Caption2$1;
exports.Tiny1 = Tiny1$1;
exports.GlobalStyle = index$b;
//# sourceMappingURL=index.js.map
